<?php
// Existing PHP code for fetching data
// Fetch data from the database
$all_departments = find_all('conn1', 'departments');
$all_users = find_all('conn1', 'users');
$all_category = find_all('conn1', 'categories');
$all_pms = find_all('conn1', 'pms');

// Fetch PMS tasks based on plan ID
$planID = $row['planID'];
$pms_tasks = [];

$query = "SELECT * FROM pms_tasks WHERE plan_id = ?";
$stmt = $conn->prepare($query);
$stmt->bind_param("i", $planID);
$stmt->execute();
$result = $stmt->get_result();

while ($task = $result->fetch_assoc()) {
    $pms_tasks[] = $task;
}

$stmt->close();
?>

<!-- Modal -->
<div class="modal fade" id="edit_pms_plan<?php echo $row['planID']; ?>" tabindex="-1" aria-labelledby="editModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <div class="modal-content text-start">
            <div class="modal-header">
                <h5 class="modal-title" id="editModalLabel"><strong>Edit PMS Plan</strong></h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <form id="editPmsForm_<?php echo $row['planID']; ?>">
                    <input type="hidden" name="plan_id" value="<?php echo $row['planID']; ?>"> <!-- Hidden field for plan ID -->

                    <!-- Department Selection -->
                    <div class="form-group mb-3">
                        <label for="department_id">Departments:</label>
                        <select class="form-control" id="department_id" name="department_id">
                            <option value="">Select Departments</option>
                            <?php foreach ($all_departments as $dept): ?>
                                <option value="<?php echo $dept['id']; ?>" <?php echo ($row['department_id'] == $dept['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($dept['department']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <!-- Branch Selection -->
                    <div class="form-group mb-3">
                        <label for="branch">Branch:</label>
                        <select class="form-control" id="branch" name="branch">
                            <option value="">Select Branch</option>
                            <option value="manila" <?php echo ($row['branch'] == 'manila') ? 'selected' : ''; ?>>Manila</option>
                            <option value="silang" <?php echo ($row['branch'] == 'silang') ? 'selected' : ''; ?>>Silang</option>
                            <option value="iloilo" <?php echo ($row['branch'] == 'iloilo') ? 'selected' : ''; ?>>Iloilo</option>
                        </select>
                    </div>

                    <!-- Infrastructure | Property -->
                    <div class="form-group mb-3">
                        <label for="property_id">Infrastructure | Property:</label>
                        <select class="form-control" id="property_id" name="property_id">
                            <option value="">Select Infrastructure | Property</option>
                            <?php foreach ($all_category as $cat): ?>
                                <option value="<?php echo $cat['id']; ?>" <?php echo ($row['property_id'] == $cat['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($cat['category']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>

                    <!-- Type Selection -->
                    <div class="form-group mb-3">
                        <label for="type">Type:</label><br>
                        <div class="form-check">
                            <input class="form-check-input" type="radio" name="type" value="maintenance" id="maintenanceRadio" <?php echo ($row['type'] == 'maintenance') ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="maintenanceRadio">Maintenance</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="radio" name="type" value="calibration" id="calibrationRadio" <?php echo ($row['type'] == 'calibration') ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="calibrationRadio">Calibration</label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="radio" name="type" value="others" id="othersCheckbox" <?php echo ($row['type'] == 'others') ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="othersCheckbox">Others</label>
                        </div>
                        <div id="othersInputDiv" style="display: <?php echo ($row['type'] == 'others') ? 'block' : 'none'; ?>; margin-top: 10px;">
                            <input type="text" class="form-control" name="specify" value="<?php echo htmlspecialchars($row['specify']); ?>" placeholder="Please specify">
                        </div>
                    </div>

                    <!-- Responsible Personnel -->
                    <div class="form-group mb-3">
                        <label for="responsible_personnel">Responsible Personnel (Position):</label>
                        <input type="text" class="form-control" name="position" value="<?php echo htmlspecialchars($row['position']); ?>" placeholder="Enter position">
                    </div>

                    <!-- Supplier to Calibrate -->
                    <div class="form-group mb-3">
                        <label for="supplier_calibrate">Supplier to Calibrate (If Applicable):</label>
                        <input type="text" class="form-control" name="supplier" value="<?php echo htmlspecialchars($row['supplier']); ?>" placeholder="Enter supplier">
                    </div>

                    <!-- PMS Plan Input (Dynamic Rows) -->
                    <div class="form-group mb-3">
                        <label for="pms_id">Tasks:</label>
                        <table class="table table-bordered" id="pmsPlanTable_<?php echo $row['planID']; ?>">
                            <thead>
                                <tr>
                                    <th>Task</th>
                                    <th width='25%'>Action</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($pms_tasks as $entry): ?>
                                    <tr>
                                        <td>
                                            <?php foreach ($all_pms as $pms): ?>
                                                <h6><?php echo ($entry['pms_id'] == $pms['id']) ? $pms['pms_name'] : ''; ?></h6>

                                            <?php endforeach; ?>
                                            </select>
                                        </td>

                                        <td>
                                            <button class="btn btn-secondary btn-sm p-2 addQuestionButton" id='add_question_btn<?php echo $entry['pms_id']; ?>'
                                                data-bs-toggle="modal" title="Add Sub unit" data-bs-target="#add_question<?php echo $entry['pms_id'] ?>" data-id="<?php echo $entry['pms_id'] ?>">
                                                <i class="fas fa-list-ul"></i>
                                            </button>
                                        </td>
                                        <!-- <td>
                                            <button type="button" class="btn btn-danger remove-row">Remove</button>
                                        </td> -->
                                    </tr>
                                    <script>
                                        $(document).ready(function() {
                                            // Ensure this event is applied to dynamically created elements
                                            $(document).on('click', '#add_question_btn<?php echo  $entry['pms_id']; ?>', function(e) {
                                                // Prevent default behavior (e.g., form submission or page reload)
                                                e.preventDefault();

                                                // Remove any existing modal backdrop to avoid multiple overlays
                                                $('.modal-backdrop').remove();

                                                // Hide the current PMS plan form (if necessary)
                                                $('#edit_pms_plan<?php echo $row['planID']; ?>').hide();

                                                // Show the correct add_question modal with a fade-in effect
                                                $('#add_question<?php echo  $entry['pms_id']; ?>').fadeIn(200, function() {
                                                    // Bootstrap modal show
                                                    $(this).modal('show');
                                                });
                                            });
                                        });
                                    </script>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                        <center>
                            <button type="button" class="btn btn-success add-row" id="addTask<?php echo $row['planID']; ?>">Add Task</button>
                        </center>
                    </div>

                    <!-- Prepared By -->
                    <div class="form-group mb-3">
                        <label for="prepared_by">Prepared By:</label>
                        <select class="form-control" id="prepared_by" name="prepared_by">
                            <option value="">Select Personnel</option>
                            <?php foreach ($all_users as $user):
                                if ($_SESSION['department_id'] == $user['department_id']) { ?>
                                    <option value="<?php echo $user['id']; ?>" <?php echo ($row['prepared_by'] == $user['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($user['firstname']) . ' ' . htmlspecialchars($user['lastname']); ?>
                                    </option>
                            <?php }
                            endforeach; ?>
                        </select>
                    </div>

                    <!-- Approved By -->
                    <div class="form-group mb-3">
                        <label for="approved_by">Approved By:</label>
                        <select class="form-control" id="approved_by" name="approved_by" <?php echo (isset($_SESSION['privilege']) && $_SESSION['privilege'] == "DEPARTMENT HEAD") ? "" : "disabled" ?>>
                            <option value="">Select Personnel</option>
                            <?php foreach ($all_users as $user):
                                foreach ($all_departments as $dept):
                                    if ($_SESSION['department_id'] == $user['department_id'] && $user['id'] == $dept['department_head']) { ?>
                                        <option value="<?php echo $user['id']; ?>" <?php echo ($row['approved_by'] == $user['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($user['firstname']) . ' ' . htmlspecialchars($user['lastname']); ?>
                                        </option>
                            <?php }
                                endforeach;
                            endforeach; ?>
                        </select>
                    </div>

                    <center>
                        <button type="button" class="btn btn-success" onclick="updatePMS('#edit_pms_plan<?php echo $row['planID']; ?>')">Update</button>
                    </center>
                </form>
            </div>
        </div>
    </div>
</div>

<script>
    // Function to fetch PMS options based on the selected property
    function fetchPMSOptions(propertyId) {
        const pmsSelects = document.querySelectorAll('.pms-select');

        // AJAX request to fetch filtered PMS based on selected property
        fetch('resources/script/pms/pms_plan/fetch_pms_by_property1.php?property_id=' + propertyId)
            .then(response => response.json())
            .then(data => {
                // Clear existing options in all PMS selects
                pmsSelects.forEach(select => {
                    select.innerHTML = '<option value="">Select PMS Plan</option>'; // Reset options

                    // Populate new options
                    data.forEach(pms => {
                        const option = document.createElement('option');
                        option.value = pms.id;
                        option.textContent = pms.pms_name; // Assuming 'pms_name' is the correct field
                        select.appendChild(option);
                    });
                });
            })
            .catch(error => console.error('Error fetching PMS:', error));
    }

    // Event listener for property selection change
    document.addEventListener('change', function(e) {
        if (e.target.id === 'property_id') {
            const propertyId = e.target.value;
            fetchPMSOptions(propertyId); // Fetch PMS options on change
        }
    });

    // Event listener for document ready (when DOM is fully loaded)
    document.addEventListener('DOMContentLoaded', function() {
        const propertyId = document.querySelector('#property_id').value; // Get selected property ID
        if (propertyId) {
            fetchPMSOptions(propertyId); // Fetch PMS options on initial load
        }
    });

    // Event listener for modal open
    document.addEventListener('show.bs.modal', function(e) {
        const propertyId = document.querySelector('#property_id').value; // Get selected property ID
        if (propertyId) {
            fetchPMSOptions(propertyId); // Fetch PMS options on modal load
        }
    });

    // Handling dynamic rows for tasks
    // document.addEventListener('click', function (e) {
    //     if (e.target.classList.contains('add-row')) {
    //         const tableBody = e.target.closest('table').querySelector('tbody');
    //         const newRow = document.createElement('tr');
    //         newRow.innerHTML = `
    //             <td>
    //                 <select class="form-control pms-select" name="pms_id[]">
    //                     <option value="">Select PMS Plan</option>
    //                     <!-- Options will be filled by AJAX -->
    //                 </select>
    //             </td>
    //             <td>
    //                 <button type="button" class="btn btn-danger remove-row">Remove</button>
    //             </td>
    //         `;
    //         tableBody.appendChild(newRow);
    //     } else if (e.target.classList.contains('remove-row')) {
    //         e.target.closest('tr').remove();
    //     }
    // });
</script>
<script>
    $(document).ready(function() {
        // jQuery function to trigger the modal
        $('#addTask<?php echo $row['planID']; ?>').on('click', function() {
            // Hide the current PMS plan form
            $('#edit_pms_plan<?php echo $row['planID']; ?>').hide();

            // Remove any existing modal backdrop


            // Animate the modal show for add_pms with a fade-in effect
            $('#add_pms<?php echo $row['planID']; ?>').fadeIn(200, function() {
                // Show the modal with Bootstrap's modal functionality
                $('.modal-backdrop').remove();
                $(this).modal('show');
            });
        });

        $('.addQuestionButton').off('click').on('click', function() {
            var pmsId = $(this).data('id');
            var assignedTo = $(this).data('assigned_to');
            $('#pms_id').val(pmsId);

            // Fetch questions via AJAX
            $.ajax({
                url: 'resources/script/pms/fetch_questions.php',
                type: 'GET',
                data: {
                    id: pmsId
                },
                dataType: 'json',
                success: function(response) {
                    // Clear existing rows
                    $('#questions tbody').empty();

                    // Add rows dynamically
                    response.forEach(function(question, index) {
                        const newRow = `
                        <tr>
                            <td class='row'>
                                <button class="btn btn-sm btn-danger py-0 col-1" type="button" onclick="rem_item(this)">
                                    <i class="fa fa-times"></i>
                                </button>
                                <span class="row-number col-1">${index + 1}.</span>
                                <input type="text" class="form-control col" name="questions[]" value="${question.task}">
                            </td>
                        </tr>
                    `;
                        $('#questions tbody').append(newRow);
                    });

                    rowCount = $('#questions tbody tr').length;
                },
                error: function(xhr, status, error) {
                    console.error('Error fetching questions:', error);
                }
            });
        });

    });
</script>