<?php
include('../database/dbcon.php');

function find_all($db, $table) {
    global $conn1, $conn2;
    $conn = ($db === "conn1") ? $conn1 : (($db === "conn2") ? $conn2 : null);

    if (!$conn) {
        return null; // Invalid database connection
    }

    $query = ($table === "items") ? "SELECT * FROM $table ORDER BY id DESC LIMIT 150" : "SELECT * FROM $table";

    $result = $conn->query($query);
    return ($result && $result->num_rows > 0) ? mysqli_fetch_all($result, MYSQLI_ASSOC) : null;
}

function find_all_where($db, $table, $where) {
    global $conn1, $conn2;
    $conn = ($db === "conn1") ? $conn1 : (($db === "conn2") ? $conn2 : null);

    if (!$conn) {
        return null; // Invalid database connection
    }

    $query = "SELECT * FROM $table WHERE $where";
    $result = $conn->query($query);
    return ($result && $result->num_rows > 0) ? mysqli_fetch_all($result, MYSQLI_ASSOC) : null;
}

// Get the ID from the URL, ensuring it's an integer
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;

if ($id > 0) {
    // Use a prepared statement to fetch the item data
    $sql2 = "SELECT items.*, categories.id AS catID, categories.code AS catCode,categories.category as categories
             FROM items 
             LEFT JOIN categories ON items.category_id = categories.id 
             WHERE items.id = ?";
                $stmt = $conn1->prepare($sql2);
                $stmt->bind_param('i', $id);
                $stmt->execute();
                $result = $stmt->get_result();

    if ($result && $result->num_rows > 0) {
        $code = $result->fetch_assoc();
        $propertyCode = $code['catCode'] . '-' . str_pad($code['code_id'], 4, '0', STR_PAD_LEFT);
    } else {
        die("No item found for the given ID.");
    }

    $stmt->close();
} else {
    die("Invalid or missing ID.");
}

// Create a new image
$IMG = imagecreatetruecolor(600, 250);

// Allocate colors
$background = imagecolorallocate($IMG, 255, 255, 255);
$text_color = imagecolorallocate($IMG, 0, 0, 0);
$line_color = imagecolorallocate($IMG, 0, 176, 240);
$line_color1 = imagecolorallocate($IMG, 0, 0, 0);

// Fill the background
imagefill($IMG, 0, 0, $background);

// Set the font path
$font_path = '../resources/ARIALBD.TTF';
$font_size = 12;

// Set the text
$branch = 'MANILA';
$text = 'PROPERTY OF COMPASS  |  ' . $branch;

// Add the main text to the image
imagettftext($IMG, $font_size, 0, 160, 85, $text_color, $font_path, $text);
imageline($IMG, 30, 90, 570, 90, $line_color);

// Draw existing lines and text
imagettftext($IMG, $font_size, 0, 30, 120, $text_color, $font_path, "Property Code:");
imageline($IMG, 250, 125, 570, 125, $line_color1);
imagettftext($IMG, $font_size, 0, 350, 120, $text_color, $font_path, isset($propertyCode) ? $propertyCode : 'N/A');

imagettftext($IMG, $font_size, 0, 30, 150, $text_color, $font_path, "Item:");
imageline($IMG, 250, 155, 570, 155, $line_color1);
imagettftext($IMG, $font_size, 0, 350, 150, $text_color, $font_path, isset($code['categories']) ? $code['categories'] : 'N/A');

imagettftext($IMG, $font_size, 0, 30, 180, $text_color, $font_path, "Location:");
imageline($IMG, 250, 185, 570, 185, $line_color1);
imagettftext($IMG, $font_size, 0, 350, 180, $text_color, $font_path, isset($code['location']) ? $code['location'] : 'N/A');

imagettftext($IMG, $font_size, 0, 30, 210, $text_color, $font_path, "Date Acquired:");
imageline($IMG, 250, 215, 570, 215, $line_color1);
imagettftext($IMG, $font_size, 0, 350, 210, $text_color, $font_path, isset($code['date_acquired']) ? substr($code['date_acquired'],-0,10) : 'N/A');

// Load and insert the logo
$logo = @imagecreatefrompng('../resources/img/compass-main-logo.png');
if ($logo) {
    $logo_width = imagesx($logo);
    $logo_height = imagesy($logo);
    $scale_factor = min(250 / $logo_width, 300 / $logo_height);
    $new_width = $logo_width * $scale_factor;
    $new_height = $logo_height * $scale_factor;
    imagecopyresampled($IMG, $logo, 10, 5, 0, 0, $new_width, $new_height, $logo_width, $logo_height);
    imagedestroy($logo);
} else {
    die('Error loading logo image.');
}

// Output image
header("Content-type: image/png");
imagepng($IMG);

// Clean up
imagedestroy($IMG);
?>
