<?php
session_start();
include('../../database/dbcon.php');
include_once('../../functions/file_handling.php');

// Check if request_disposal is set
if (isset($_POST['property_codes'])) {
    $response = []; // Initialize response array

    $propertyCodes = array_unique(explode(",", substr($_POST['property_codes'], 0, -1)));
    $target_dir_photo = "../../resources/img/upload_tag/";
    $target_dir_report = "../../resources/img/upload_status/";
    
    // Fetch the ID of the status with status 'FOR DISPOSAL'
    $sql3 = "SELECT id FROM status WHERE status = 'FOR DISPOSAL'";
    $stmt3 = $conn1->prepare($sql3);
    $stmt3->execute();
    $result3 = $stmt3->get_result();
    $status_row = $result3->fetch_assoc();
    $status_id = $status_row['id'];
    $stmt3->close();
    
    // Retrieve the submitted form data
    $dept_head = $_POST['dept_head_approve']; // 1 for approval, 0 for disapproval
    $reason = (isset($_POST['reason']) && $_POST['reason'] === "Other") ? $_POST['other_reason_specify'] : $_POST['reason'];
    $method = (isset($_POST['method']) && $_POST['method'] === "OTHER") ? $_POST['other_disposal_specify'] : $_POST['method'];
    
    // Initialize an array to hold item IDs
    $item_ids = [];
    
    // Process each property code individually
    foreach ($propertyCodes as $propertyCode) {
        // Split the property code into its components (deptCode, catCode, code_id)
        list($deptCode, $catCode, $code_id) = explode("-", $propertyCode);
    
        // Sanitize each component if necessary
        $deptCode = mysqli_real_escape_string($conn1, $deptCode);
        $catCode = mysqli_real_escape_string($conn1, $catCode);
        $code_id = mysqli_real_escape_string($conn1, $code_id);
    
        // Search for the items.id using the three parameters with LEFT JOIN on departments and categories
        $query = "
            SELECT items.id 
            FROM items
            LEFT JOIN departments ON departments.id = items.department_id
            LEFT JOIN categories ON categories.id = items.category_id
            WHERE departments.code = ? AND categories.code = ? AND items.code_id = ?
            LIMIT 1";
        $stmt = $conn1->prepare($query);
        $stmt->bind_param("ssi", $deptCode, $catCode, $code_id); // Assuming code_id is an integer
        $stmt->execute();
        $result = $stmt->get_result();
    
        if ($result->num_rows > 0) {
            $item_row = $result->fetch_assoc();
            $item_ids[] = $item_row['id']; // Add found item_id to the array
        } else {
            echo "No item found for $deptCode-$catCode-$code_id<br>";
        }
    
        // Close the statement
        $stmt->close();
    }

    $item_id = implode(",", $item_ids);

      

    // Secure the inputs to prevent SQL injection
    $reason = strtoupper(mysqli_real_escape_string($conn1, $reason));
    $method = strtoupper(mysqli_real_escape_string($conn1, $method));

    if (isset($_POST['status_report_id']) && !empty($_POST['status_report_id'])) {
        $status_report_id = mysqli_real_escape_string($conn1, $_POST['status_report_id']);
        $stat_code = explode('-', $_POST['status_report_id']);
        $dept_code = $stat_code[0];
        $year = $stat_code[2];
        $code_id = ltrim($stat_code[3], '0');

        // Prepare and bind the department query
        $stmt = $conn1->prepare("SELECT id FROM departments WHERE code = ?");
        $stmt->bind_param("s", $dept_code);
        $stmt->execute();
        $dept_result = $stmt->get_result();

        if ($deptID = $dept_result->fetch_assoc()) {
            $stmt->close();

            // Prepare and bind the status report query
            $stmt = $conn1->prepare("SELECT id FROM status_report_1 WHERE department_id = ? AND code_id = ? AND date_requested LIKE ?");
            $like_year = '%' . $year . '%';
            $stmt->bind_param("iis", $deptID['id'], $code_id, $like_year);
            $stmt->execute();
            $stat_result = $stmt->get_result();

            if ($statID = $stat_result->fetch_assoc()) {
                $status_report_id = $statID['id'];
                $response['status'] = 'success';
                $response['message'] = 'Status report found';
            } else {
                $response['status'] = 'error';
                $response['message'] = 'Invalid status report: No matching record found';
                $status_report_id = NULL;
            }

            $stmt->close();
        } else {
            $response['status'] = 'error';
            $response['message'] = 'Invalid department code: No matching record found';
            $status_report_id = NULL;
            $stmt->close();
        }
    } else {
        $status_report_id = NULL;
    }


    // Assuming $department_id is already available or retrieved from somewhere
    $department_id = $_SESSION['department_id']; // Retrieve this based on your specific logic
    $currYear = date("Y"); // Current year

    // Get the last year from the approved_date in disposal_history filtered by department_id
    $result = $conn1->query("
        SELECT YEAR(MAX(dh.approved_date)) AS last_year
        FROM disposal_history dh
        LEFT JOIN disposal_logs dl ON dh.disposal_id = dl.id
        LEFT JOIN items i ON dl.item_id = i.id
        WHERE i.department_id = $department_id
    ");

    $row = $result->fetch_assoc();
    $last_year = $row['last_year'];

    // If the current year is greater than the last year, set $new_code_id to 1
    if ($currYear > $last_year) {
        $new_code_id = 1;
    } else {
        // Get the total number of rows in disposal_logs filtered by department_id
        $result = $conn1->query("
            SELECT COUNT(*) AS total_rows 
            FROM disposal_logs 
            LEFT JOIN items ON disposal_logs.item_id = items.id
            WHERE items.department_id = $department_id
        ");
        $row = $result->fetch_assoc();
        $total_rows = $row['total_rows'];

        // Retrieve the last code_id from the disposal_logs table filtered by department_id
        $result = $conn1->query("
            SELECT MAX(disposal_logs.code_id) AS last_code_id 
            FROM disposal_logs 
            LEFT JOIN items ON disposal_logs.item_id = items.id
            WHERE items.department_id = $department_id
        ");
        $row = $result->fetch_assoc();
        $last_code_id = $row['last_code_id'];

        // Determine the new code_id based on total_rows and last_code_id
        if ($last_code_id && $last_code_id >= ($total_rows + 1)) {
            $new_code_id = $last_code_id + 1;
        } else {
            $new_code_id = $total_rows + 1;
        }
    }

    // $new_code_id is now ready to be used for further processing



    // Use prepared statements to secure the query and insert the data
    $stmt = $conn1->prepare("INSERT INTO disposal_logs (item_id, code_id, dept_head, status_report_id, reason, method) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("siisss", $item_id, $new_code_id, $dept_head, $status_report_id, $reason, $method);

    if ($stmt->execute()) {
        // Get the current year
        $year = date("Y");

        // Retrieve the last inserted ID from disposal_logs
        $last_id = $conn1->insert_id;

        // Retrieve the relevant row data using a LEFT JOIN to get code and code_id
        $query = "
        SELECT departments.code, disposal_logs.code_id, departments.department 
        FROM disposal_logs 
        LEFT JOIN items ON items.id = disposal_logs.item_id 
        LEFT JOIN departments ON items.department_id = departments.id 
        WHERE disposal_logs.id = ?";
        $stmt = $conn1->prepare($query);
        $stmt->bind_param("i", $last_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $row = $result->fetch_assoc();


        if ($row) {
            // Format the form control number
            $form_control_no = $row['code'] . "-DIS-" . $year . "-" . str_pad($row['code_id'], 4, "0", STR_PAD_LEFT);
        } else {
            $response = [
                "status" => "error",
                "message" => "Record not found."
            ];
            echo json_encode($response);
            exit;
        }

        $stmt->close();

        // Handle photo equipment upload
        if (isset($_FILES["upload_tag"])) {
            $upload_tag = $_FILES["upload_tag"];
            $fileNameCmps = explode(".", $upload_tag["name"]);
            $fileExtension = strtolower(end($fileNameCmps));

            // Use the form control number as the filename
            $upload_tag_filename = $form_control_no . "." . $fileExtension;
            $upload_tag_path = $target_dir_photo . $upload_tag_filename;
            if (!move_uploaded_file($upload_tag["tmp_name"], $upload_tag_path)) {
                if (isset($_POST['upload_tag_hidden'])) {
                    $upload_tag_filename = $_POST['upload_tag_hidden'];
                } else {
                    $response = [
                        "status" => "error",
                        "message" => "Sorry, there was an error uploading your photo equipment file."
                    ];
                    echo json_encode($response);
                    exit;
                }
            }
        } else {
            if (isset($_POST['upload_tag_hidden'])) {
                $upload_tag_filename = $_POST['upload_tag_hidden'];
            } else {
                $response = [
                    "status" => "error",
                    "message" => "Photo equipment file is required."
                ];
                echo json_encode($response);
                exit;
            }
        }

        // Handle service report upload
        if (isset($_FILES["upload_status"])) {
            $upload_status = $_FILES["upload_status"];
            $fileNameCmps = explode(".", $upload_status["name"]);
            $fileExtension = strtolower(end($fileNameCmps));

            // Use the form control number as the filename
            $upload_status_filename = $form_control_no . "." . $fileExtension;
            $upload_status_path = $target_dir_report . $upload_status_filename;
            if (!move_uploaded_file($upload_status["tmp_name"], $upload_status_path)) {
                if (isset($_POST['upload_status_hidden'])) {
                    $upload_status_filename = $_POST['upload_status_hidden'];
                } else {
                    $upload_status_filename = NULL;
                }
            }
        } else {
            if (isset($_POST['upload_status_hidden'])) {
                $upload_status_filename = $_POST['upload_status_hidden'];
            } else {
                $response = [
                    "status" => "error",
                    "message" => "Service report file is required."
                ];
                echo json_encode($response);
                exit;
            }
        }

        // Prepare an SQL statement for inserting or updating the items table
        $sql = "UPDATE items 
        SET upload_tag = ?, upload_status = ?, status_id = ? 
        WHERE id = ?";

        // Prepare the statement
        if ($stmt = $conn1->prepare($sql)) {
            // Bind parameters
            $stmt->bind_param("ssii", $upload_tag_filename, $upload_status_filename, $status_id, $id);

            // Execute the statement
            $stmt->execute();

            // Check if the update was successful
            if ($stmt->affected_rows > 0) {

                    $response["status"] = "success";
                    $response["message"] = "Items table updated successfully.";

            }

            // Close the statement
            $stmt->close();
        } else {
                $response["status"] = "error";
                $response["message"] = "Error preparing statement: {$conn1->error}";
        }

        // Return the response as JSON
        echo json_encode($response);


        // Insert into disposal_history table
        $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
        $approved_type = $dept_head ? "dept_head" : "dept_head"; // dept_head for both approval and disapproval

        $stmt2 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
        $stmt2->bind_param("iis", $last_id, $approved_by, $approved_type);

        if ($stmt2->execute()) {
            //notification
            $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
            $sql4 = "INSERT INTO notification_records (sender_id, item_id, department_id, content, link)
            VALUES ('$sender_id', '$last_id', '$department_id', 'requested a disposal.', 'for_disposal_item.php?form_control_no')
            ON DUPLICATE KEY UPDATE
                timestamp = CURRENT_TIMESTAMP";
            $result1 = mysqli_query($conn1, $sql4);

            $response['status'] = 'success';
            $response['message'] = 'Records inserted successfully';
        } else {
            $response['message'] = 'Error inserting into disposal_history: ' . $stmt2->error;
        }

        $stmt2->close();
    } else {
        $response['message'] = 'Error inserting into disposal_logs: ' . $stmt->error;
    }

    mysqli_close($conn1);

    // Return the JSON response
    echo json_encode($response);
}
?>