<?php
session_start();
include('../../database/dbcon.php');
include_once('../../functions/file_handling.php');

// Check if request_disposal is set
if (isset($_POST['request_disposal'])) {
    $response = []; // Initialize response array

    // Sanitize and retrieve form data
    $id = $_POST['id'];
    $target_dir_photo = "../../resources/img/upload_tag/";
    $target_dir_report = "../../resources/img/upload_status/";

    // Fetch property code
    $sql2 = "SELECT items.*, categories.*, categories.id AS catID, categories.code AS catCode, departments.id AS deptID, departments.code AS deptCode FROM items 
                LEFT JOIN categories ON items.category_id = categories.id 
                LEFT JOIN departments ON items.department_id = departments.id 
                WHERE items.id = ?";
    $stmt2 = $conn1->prepare($sql2);
    $stmt2->bind_param('i', $id);
    $stmt2->execute();
    $result = $stmt2->get_result();
    $code = $result->fetch_assoc();
    $stmt2->close();

    // Fetch the ID of the status with status 'FOR DISPOSAL'
    $sql3 = "SELECT id FROM status WHERE status = 'FOR DISPOSAL'";
    $stmt3 = $conn1->prepare($sql3);
    $stmt3->execute();
    $result3 = $stmt3->get_result();
    $status_row = $result3->fetch_assoc();
    $status_id = $status_row['id'];
    $stmt3->close();

    // Generating property code
    $propertyCode = $code['deptCode'] . '-' . $code['catCode'] . '-' . str_pad($code['code_id'], 4, '0', STR_PAD_LEFT);

    // Handle photo equipment upload
    if (isset($_FILES["upload_tag"])) {
        $upload_tag = $_FILES["upload_tag"];
        $fileNameCmps = explode(".", $upload_tag["name"]);
        $fileExtension = strtolower(end($fileNameCmps));

        $upload_tag_filename = $propertyCode . "." . $fileExtension;
        $upload_tag_path = $target_dir_photo . $upload_tag_filename;
        if (!move_uploaded_file($upload_tag["tmp_name"], $upload_tag_path)) {
            if (isset($_POST['upload_tag_hidden'])) {
                $upload_tag_filename = $_POST['upload_tag_hidden'];
            } else {
                $response = [
                    "status" => "error",
                    "message" => "Sorry, there was an error uploading your photo equipment file."
                ];
                echo json_encode($response);
                exit;
            }
        }
    } else {
        if (isset($_POST['upload_tag_hidden'])) {
            $upload_tag_filename = $_POST['upload_tag_hidden'];
        } else {
            $response = [
                "status" => "error",
                "message" => "Photo equipment file is required."
            ];
            echo json_encode($response);
            exit;
        }
    }

    // Handle service report upload
    if (isset($_FILES["upload_status"])) {
        $upload_status = $_FILES["upload_status"];
        $fileNameCmps = explode(".", $upload_status["name"]);
        $fileExtension = strtolower(end($fileNameCmps));

        $upload_status_filename = $propertyCode . "." . $fileExtension;
        $upload_status_path = $target_dir_report . $upload_status_filename;
        if (!move_uploaded_file($upload_status["tmp_name"], $upload_status_path)) {
            if (isset($_POST['upload_status_hidden'])) {
                $upload_status_filename = $_POST['upload_status_hidden'];
            } else {
                $upload_status_filename = NULL;
            }
        }
    } else {
        if (isset($_POST['upload_status_hidden'])) {
            $upload_status_filename = $_POST['upload_status_hidden'];
        } else {
            $response = [
                "status" => "error",
                "message" => "Service report file is required."
            ];
            echo json_encode($response);
            exit;
        }
    }

    // Prepare an SQL statement for inserting or updating the items table
    $sql = "UPDATE items 
            SET upload_tag = ?, upload_status = ?, status_id = ? 
            WHERE id = ?";

    // Prepare the statement
    if ($stmt = $conn1->prepare($sql)) {
        // Bind parameters
        $stmt->bind_param("ssii", $upload_tag_filename, $upload_status_filename, $status_id, $id);

        // Execute the statement
        $stmt->execute();

        // Check if the update was successful
        if ($stmt->affected_rows > 0) {
            $response = [
                "status" => "success",
                "message" => "Items table updated successfully."
            ];
        } else {
            $response = [
                "status" => "error",
                "message" => "No changes made to the items table."
            ];
        }

        // Close the statement
        $stmt->close();
    } else {
        $response = [
            "status" => "error",
            "message" => "Error preparing statement: {$conn1->error}"
        ];
    }

    $response = array('status' => 'error', 'message' => 'An error occurred.');

    // Retrieve the submitted form data
    $item_id = $_POST['id'];
    $dept_head = $_POST['dept_head_approve']; // 1 for approval, 0 for disapproval
    $reason = (isset($_POST['reason']) && $_POST['reason'] === "Other") ? $_POST['other_reason_specify'] : $_POST['reason'];
    $method = (isset($_POST['method']) && $_POST['method'] === "OTHER") ? $_POST['other_disposal_specify'] : $_POST['method'];

    // Secure the inputs to prevent SQL injection
    $item_id = mysqli_real_escape_string($conn1, $item_id);
    $reason = strtoupper(mysqli_real_escape_string($conn1, $reason));
    $method = strtoupper(mysqli_real_escape_string($conn1, $method));

    if(isset($_POST['status_report_id']) && !empty($_POST['status_report_id'])) {
        $status_report_id = mysqli_real_escape_string($conn1, $_POST['status_report_id']);
        $stat_code = explode('-', $_POST['status_report_id']);
        $dept_code = $stat_code[0];
        $year = $stat_code[2];
        $code_id = ltrim($stat_code[3], '0');
    
        // Prepare and bind the department query
        $stmt = $conn1->prepare("SELECT id FROM departments WHERE code = ?");
        $stmt->bind_param("s", $dept_code);
        $stmt->execute();
        $dept_result = $stmt->get_result();
        
        if ($deptID = $dept_result->fetch_assoc()) {
            $stmt->close();
    
            // Prepare and bind the status report query
            $stmt = $conn1->prepare("SELECT id FROM status_report_1 WHERE department_id = ? AND code_id = ? AND date_requested LIKE ?");
            $like_year = '%' . $year . '%';
            $stmt->bind_param("iis", $deptID['id'], $code_id, $like_year);
            $stmt->execute();
            $stat_result = $stmt->get_result();
            
            if ($statID = $stat_result->fetch_assoc()) {
                $status_report_id = $statID['id'];
                $response['status'] = 'success';
                $response['message'] = 'Status report found';
            } else {
                $response['status'] = 'error';
                $response['message'] = 'Invalid status report: No matching record found';
                $status_report_id = NULL;
            }
            
            $stmt->close();
        } else {
            $response['status'] = 'error';
            $response['message'] = 'Invalid department code: No matching record found';
            $status_report_id = NULL;
            $stmt->close();
        }
    } else {
        $status_report_id = NULL;
    }
    

    // Assuming $department_id is already available or retrieved from somewhere
    $department_id = $_SESSION['department_id']; // Retrieve this based on your specific logic
    $currYear = date("Y"); // Current year

    // Get the last year from the approved_date in disposal_history filtered by department_id
    $result = $conn1->query("
        SELECT YEAR(MAX(dh.approved_date)) AS last_year
        FROM disposal_history dh
        LEFT JOIN disposal_logs dl ON dh.disposal_id = dl.id
        LEFT JOIN items i ON dl.item_id = i.id
        WHERE i.department_id = $department_id
    ");

    $row = $result->fetch_assoc();
    $last_year = $row['last_year'];

    // If the current year is greater than the last year, set $new_code_id to 1
    if ($currYear > $last_year) {
        $new_code_id = 1;
    } else {
        // Get the total number of rows in disposal_logs filtered by department_id
        $result = $conn1->query("
            SELECT COUNT(*) AS total_rows 
            FROM disposal_logs 
            LEFT JOIN items ON disposal_logs.item_id = items.id
            WHERE items.department_id = $department_id
        ");
        $row = $result->fetch_assoc();
        $total_rows = $row['total_rows'];

        // Retrieve the last code_id from the disposal_logs table filtered by department_id
        $result = $conn1->query("
            SELECT MAX(disposal_logs.code_id) AS last_code_id 
            FROM disposal_logs 
            LEFT JOIN items ON disposal_logs.item_id = items.id
            WHERE items.department_id = $department_id
        ");
        $row = $result->fetch_assoc();
        $last_code_id = $row['last_code_id'];

        // Determine the new code_id based on total_rows and last_code_id
        if ($last_code_id && $last_code_id >= ($total_rows + 1)) {
            $new_code_id = $last_code_id + 1;
        } else {
            $new_code_id = $total_rows + 1;
        }
    }

    // $new_code_id is now ready to be used for further processing



    // Use prepared statements to secure the query and insert the data
    $stmt = $conn1->prepare("INSERT INTO disposal_logs (item_id, code_id, dept_head, status_report_id, reason, method) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("iiisss", $item_id, $new_code_id, $dept_head, $status_report_id, $reason, $method);

    if ($stmt->execute()) {
        // Retrieve the last inserted ID
        $last_id = $conn1->insert_id;

        // Insert into disposal_history table
        $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
        $approved_type = $dept_head ? "dept_head" : "dept_head"; // dept_head for both approval and disapproval

        $stmt2 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
        $stmt2->bind_param("iis", $last_id, $approved_by, $approved_type);

        if ($stmt2->execute()) {
            //notification
            $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
            $sql4 = "INSERT INTO notification_records (sender_id, item_id, department_id, content, link)
            VALUES ('$sender_id', '$last_id', '$department_id', 'requested a disposal.', 'for_disposal_item.php?form_control_no')
            ON DUPLICATE KEY UPDATE
                timestamp = CURRENT_TIMESTAMP";
            $result1 = mysqli_query($conn1, $sql4);

            $response['status'] = 'success';
            $response['message'] = 'Records inserted successfully';
        } else {
            $response['message'] = 'Error inserting into disposal_history: ' . $stmt2->error;
        }

        $stmt2->close();
    } else {
        $response['message'] = 'Error inserting into disposal_logs: ' . $stmt->error;
    }

    $stmt->close();
    mysqli_close($conn1);

    // Return the JSON response
    echo json_encode($response);
}


//Nakatap dito yung approve ng gm kasi wala namang gm sa silang
if (isset($_POST['pam_approve'])) {
    $response = array('status' => 'error', 'message' => 'An error occurred.');

    $id = $_POST['id'];
    $pam_approve = $_POST['pam_approve'];
    $gm_approve = $_POST['gm_approve'];
    $pam = ($pam_approve == 'approve') ? 1 : 0; 
    $general_manager = ($gm_approve == 'approve') ? 1 : 0; 
    $pam_remarks = isset($_POST['pam_remarks']) ? $_POST['pam_remarks'] : '';

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);
    $pam_remarks = mysqli_real_escape_string($conn1, $pam_remarks);

    // Update the disposal_logs table with the PAM approval and remarks
    $stmt = $conn1->prepare("UPDATE disposal_logs SET pam = ?, general_manager = ?, pam_remarks = ? WHERE id = ?");
    $stmt->bind_param("iisi", $pam, $general_manager, $pam_remarks, $id);

    if ($stmt->execute()) {
        // Retrieve the ID from disposal_logs table using id
        $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
        $stmt1->bind_param("i", $id);
        $stmt1->execute();
        $stmt1->bind_result($last_id);
        $stmt1->fetch();
        $stmt1->close();

        if ($last_id) {
            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "pam";

            $stmt2 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt2->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt2->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Records updated successfully';
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt2->error;
            }

            $stmt2->close();
        } else {
            $response['message'] = 'No matching record found in disposal_logs';
        }
    } else {
        $response['message'] = 'Error updating record: ' . $stmt->error;
    }

    $stmt->close();
    mysqli_close($conn1);

    // Return the JSON response
    echo json_encode($response);
}

if (isset($_POST['financemngr_approve'])) {
    $response = array('status' => 'error', 'message' => 'An error occurred.');
    $id = $_POST['id'];
    $finance_manager = 1; // Assuming finance_manager value to be inserted is 1 (approved)
    $depreciated_amt = $_POST['depreciated_amt'];
    $finance_remarks = $_POST['financemngr_remarks'];

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);
    $depreciated_amt = mysqli_real_escape_string($conn1, $depreciated_amt);

    // Update the depreciated_amt column using the id
    $stmt = $conn1->prepare("UPDATE disposal_logs SET finance_manager = ?, finance_remarks = ?, depreciated_amt = ? WHERE id = ?");
    $stmt->bind_param("isdi", $finance_manager, $finance_remarks, $depreciated_amt, $id);

    if ($stmt->execute()) {
        // Retrieve the ID from disposal_logs table using id
        $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
        $stmt1->bind_param("i", $id);
        $stmt1->execute();
        $stmt1->bind_result($last_id);
        $stmt1->fetch();
        $stmt1->close();

        if ($last_id) {
            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "financemngr";

            $stmt2 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt2->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt2->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Records updated successfully';
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt2->error;
            }

            $stmt2->close();
        } else {
            $response['message'] = 'No matching record found in disposal_logs';
        }
    } else {
        $response['message'] = 'Error updating record: ' . $stmt->error;
    }

    $stmt->close();
    mysqli_close($conn1);

    // Return the JSON response
    echo json_encode($response);
}

if (isset($_POST['generalmngr_approve'])) {
    $id = $_POST['id'];
    $general_manager = 1; // Assuming general_manager value to be inserted is 1 (approved)

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);

    // Retrieve the ID from disposal_logs table using id
    $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
    $stmt1->bind_param("i", $id);
    $stmt1->execute();
    $stmt1->bind_result($last_id);
    $stmt1->fetch();
    $stmt1->close();

    if ($last_id) {
        // Update general_manager value in disposal_logs table
        $stmt2 = $conn1->prepare("UPDATE disposal_logs SET general_manager = ? WHERE id = ?");
        $stmt2->bind_param("ii", $general_manager, $last_id);

        if ($stmt2->execute()) {
            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "generalmngr";

            $stmt3 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt3->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt3->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Records updated successfully';
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt3->error;
            }

            $stmt3->close();
        } else {
            $response['message'] = 'Error updating disposal_logs: ' . $stmt2->error;
        }

        $stmt2->close();
        mysqli_close($conn1);
    } else {
        $response['message'] = 'No matching record found in disposal_logs';
    }
    // Return the JSON response
    echo json_encode($response);
}

if (isset($_POST['president_approve'])) {
    $response = array('status' => 'error', 'message' => 'An error occurred.');
    $id = $_POST['id'];
    $propertyCode = $_POST['propertyCode'];
    $president_approve = $_POST['president_approve']; // Get the approval status from the form

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);
    $president_approve = mysqli_real_escape_string($conn1, $president_approve);

    // Handle file upload
    $upload_dir = '../../resources/img/upload_disposal/';
    $uploaded_file = '';

    if (isset($_FILES["upload_disposal"])) {
        $upload_disposal = $_FILES["upload_disposal"];
        $fileNameCmps = explode(".", $upload_disposal["name"]);
        $fileExtension = strtolower(end($fileNameCmps));

        // Generating a unique file name using id and extension
        $upload_disposal_filename = $propertyCode . "." . $fileExtension;
        $upload_disposal_path = $upload_dir . $upload_disposal_filename;

        // Attempt to move the uploaded file to the target directory
        if (!move_uploaded_file($upload_disposal["tmp_name"], $upload_disposal_path)) {
            if (isset($_POST['upload_disposal_hidden'])) {
                // Use the existing file if a new one wasn't uploaded
                $upload_disposal_filename = $_POST['upload_disposal_hidden'];
            } else {
                $response['message'] = 'Sorry, there was an error uploading your file.';
                echo json_encode($response);
                exit;
            }
        }
    } else {
        if (isset($_POST['upload_disposal_hidden'])) {
            // Use the existing file if no new file is provided
            $upload_disposal_filename = $_POST['upload_disposal_hidden'];
        } else {
            $response['message'] = 'A file is required.';
            echo json_encode($response);
            exit;
        }
    }

    // Retrieve the ID from disposal_logs table using id
    $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
    $stmt1->bind_param("i", $id);
    $stmt1->execute();
    $stmt1->bind_result($last_id);
    $stmt1->fetch();
    $stmt1->close();

    if ($last_id) {
        // Update president value and upload_disposal in disposal_logs table
        $stmt2 = $conn1->prepare("UPDATE disposal_logs SET president = ?, upload_disposal = ? WHERE id = ?");
        $stmt2->bind_param("isi", $president_approve, $upload_disposal_filename, $last_id);

        if ($stmt2->execute()) {
            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "president";

            $stmt3 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt3->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt3->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Records updated successfully';
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt3->error;
            }

            $stmt3->close();
        } else {
            $response['message'] = 'Error updating disposal_logs: ' . $stmt2->error;
        }

        $stmt2->close();
    } else {
        $response['message'] = 'No matching record found in disposal_logs';
    }
    
    mysqli_close($conn1);
    
    // Return the JSON response
    echo json_encode($response);
}


if (isset($_POST['admin_approve'])) {
    $response = array('status' => 'error', 'message' => 'An error occurred.');
    $id = $_POST['id'];
    $ack_receipt = $_FILES["ack_receipt"];
    $propertyCode = $_POST['propertyCode'];
    $fileNameCmps = explode(".", $ack_receipt["name"]);
    $fileExtension = strtolower(end($fileNameCmps));
    $admin = 1; // Assuming admin value to be inserted is 1 (approved)

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);

    // Retrieve the ID from disposal_logs table using id
    $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
    $stmt1->bind_param("i", $id);
    $stmt1->execute();
    $stmt1->bind_result($last_id);
    $stmt1->fetch();
    $stmt1->close();

    if ($last_id) {
        // Update admin value in disposal_logs table
        $stmt2 = $conn1->prepare("UPDATE disposal_logs SET admin = ? WHERE id = ?");
        $stmt2->bind_param("ii", $admin, $last_id);

        if ($stmt2->execute()) {
            // Check if an acknowledgment receipt was uploaded
            if (isset($_FILES['ack_receipt']) && $_FILES['ack_receipt']['error'] == 0) {
                $target_dir = "../../resources/img/ack_receipt/";
                $target_file = $target_dir . $propertyCode . $fileExtension;
                $uploadOk = 1;
                $imageFileType = strtolower(pathinfo($target_file, PATHINFO_EXTENSION));

                // Check if file already exists
                if (file_exists($target_file)) {
                    $response['message'] = 'Sorry, file already exists.';
                    $uploadOk = 0;
                }

                // Check file size
                if ($_FILES["ack_receipt"]["size"] > 5000000) {
                    $response['message'] = 'Sorry, your file is too large.';
                    $uploadOk = 0;
                }

                // Allow certain file formats
                $allowed_types = array("jpg", "jpeg", "png", "pdf", "doc", "docx");
                if (!in_array($imageFileType, $allowed_types)) {
                    $response['message'] = 'Sorry, only JPG, JPEG, PNG, PDF, DOC & DOCX files are allowed.';
                    $uploadOk = 0;
                }

                if ($uploadOk == 1) {
                    if (move_uploaded_file($_FILES["ack_receipt"]["tmp_name"], $target_file)) {
                        $ack_receipt = basename($_FILES["ack_receipt"]["name"]);

                        // Update disposal_logs table with the acknowledgement receipt file name
                        $stmt3 = $conn1->prepare("UPDATE disposal_logs SET ack_receipt = ? WHERE id = ?");
                        $stmt3->bind_param("si", $ack_receipt, $last_id);
                        $stmt3->execute();
                        $stmt3->close();
                    } else {
                        $response['message'] = 'Sorry, there was an error uploading your file.';
                    }
                }
            }

            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "admin";

            $stmt4 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt4->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt4->execute()) {
                // Fetch status_id from status table where status = "DISPOSED"
                $stmt5 = $conn1->prepare("SELECT id FROM status WHERE status = 'DISPOSED'");
                $stmt5->execute();
                $stmt5->bind_result($status_id);
                $stmt5->fetch();
                $stmt5->close();

                // Update the status_id in the items table
                $stmt6 = $conn1->prepare("UPDATE items SET status_id = ? WHERE id = ?");
                $stmt6->bind_param("ii", $status_id, $id);

                if ($stmt6->execute()) {
                    $response['status'] = 'success';
                    $response['message'] = 'Records updated successfully.';
                } else {
                    $response['message'] = 'Error updating item status: ' . $stmt6->error;
                }

                $stmt6->close();
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt4->error;
            }

            $stmt4->close();
        } else {
            $response['message'] = 'Error updating disposal_logs: ' . $stmt2->error;
        }

        $stmt2->close();
        mysqli_close($conn1);
    } else {
        $response['message'] = 'No matching record found in disposal_logs';
    }
    // Return the JSON response
    echo json_encode($response);
}

if (isset($_POST['financemngr1_approve'])) {
    $response = array('status' => 'error', 'message' => 'An error occurred.');

    $id = $_POST['id'];
    $sales_amt = $_POST['sales_amt'];

    // Secure the input to prevent SQL injection
    $id = mysqli_real_escape_string($conn1, $id);
    $sales_amt = mysqli_real_escape_string($conn1, $sales_amt);

    // Retrieve the ID from disposal_logs table using id
    $stmt1 = $conn1->prepare("SELECT id FROM disposal_logs WHERE id = ?");
    $stmt1->bind_param("i", $id);
    $stmt1->execute();
    $stmt1->bind_result($last_id);
    $stmt1->fetch();
    $stmt1->close();

    if ($last_id) {
        // Update sales_amt in disposal_logs table
        $stmt2 = $conn1->prepare("UPDATE disposal_logs SET sales_amt = ? WHERE id = ?");
        $stmt2->bind_param("di", $sales_amt, $last_id);

        if ($stmt2->execute()) {
            // Insert into disposal_history table
            $approved_by = $_SESSION['id']; // Assuming 'id' is stored in the session
            $approved_type = "financemngr1";

            $stmt3 = $conn1->prepare("INSERT INTO disposal_history (disposal_id, approved_by, approved_type) VALUES (?, ?, ?)");
            $stmt3->bind_param("iis", $last_id, $approved_by, $approved_type);

            if ($stmt3->execute()) {
                $response['status'] = 'success';
                $response['message'] = 'Records updated successfully';
            } else {
                $response['message'] = 'Error inserting into disposal_history: ' . $stmt3->error;
            }

            $stmt3->close();
        } else {
            $response['message'] = 'Error updating disposal_logs: ' . $stmt2->error;
        }

        $stmt2->close();
    } else {
        $response['message'] = 'No matching record found in disposal_logs';
    }
    mysqli_close($conn1);

    // Return the JSON response
    echo json_encode($response);
}
