<?php
require_once('../../database/dbcon.php');
session_start(); // Start the session

if ($_SERVER['REQUEST_METHOD'] === 'POST') {

    // Ensure the 'questions' field is set and is an array
    if (!isset($_POST['questions']) || !is_array($_POST['questions'])) {
        echo "Required fields are missing or data format is incorrect";
        exit;
    }

    // Retrieve the data array
    $questions = $_POST['questions'];

    // Retrieve the current session ID (or user ID) for answered_by
    $answered_by = isset($_SESSION['id']) ? $_SESSION['id'] : null; // Adjust this as per your session variable for user ID

    // Prepare the SQL statement for bulk insertion or update
    $sql = "INSERT INTO pms_answers (pms_id, asset_id, question_id, item_id, is_checked, date_answered, remarks, answered_by) VALUES ";

    // Prepare placeholders and values arrays
    $placeholders = [];
    $values = [];

    // Get the last index of questions (assuming the last entry contains the remarks)
    $last_question = end($questions);
    $remarks = isset($last_question['remarks']) ? $last_question['remarks'] : '';

    // Create placeholders and values for each set of data
    foreach ($questions as $key => $question) {
        // Skip the last entry if it's for remarks only
        if (isset($question['remarks'])) {
            continue;
        }

        // Ensure required fields exist
        if (!isset($question['pms_id'], $question['asset_id'], $question['question_id'], $question['item_id'])) {
            continue; // Skip if required fields are missing
        }

        // Check if 'is_checked' exists, and default it to 0 if not
        $is_checked = isset($question['is_checked']) ? $question['is_checked'] : 0;

        // Add the placeholders and values
        $placeholders[] = "(?, ?, ?, ?, ?, ?, ?, ?)";
        $values[] = $question['pms_id'];
        $values[] = $question['asset_id'];
        $values[] = $question['question_id'];
        $values[] = $question['item_id'];
        $values[] = $is_checked;
        $values[] = isset($question['date_answered']) ? $question['date_answered'] : date('Y-m-d H:i:s'); // Default to now if not set
        $values[] = $remarks; // Use the extracted remarks for all entries
        $values[] = $answered_by; // Adding answered_by to the values
    }

    // If there are no valid rows to insert, exit
    if (empty($placeholders)) {
        echo "No valid data to insert";
        exit;
    }

    // Append placeholders to the SQL statement
    $sql .= implode(', ', $placeholders);
    
    // Add the ON DUPLICATE KEY UPDATE clause
    $sql .= " ON DUPLICATE KEY UPDATE 
                is_checked = VALUES(is_checked), 
                date_answered = VALUES(date_answered), 
                remarks = VALUES(remarks), 
                answered_by = VALUES(answered_by)";

    // Prepare the statement
    if ($stmt = $conn1->prepare($sql)) {
        // Bind parameters dynamically
        $types = str_repeat('iiiiissi', count($placeholders)); // 6 integers and 2 strings per row
        $stmt->bind_param($types, ...$values);

        // Execute the statement
        if ($stmt->execute()) {
            echo "success";
        } else {
            // Log the error
            error_log("Failed to execute statement: " . $stmt->error);
            echo "error";
        }

        // Close the statement
        $stmt->close();
    } else {
        // Log the error
        error_log("Failed to prepare statement: " . $conn1->error);
        echo "error";
    }

    // Close the database connection
    $conn1->close();
}
?>
