<?php
require_once('../../database/dbcon.php');
ob_start();
session_start();

// Set content type to JSON
header('Content-Type: application/json');

// Check if the request method is POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve and sanitize input data
    $plan_id = htmlspecialchars(trim($_POST['plan_id']));
    $item_id = htmlspecialchars(trim($_POST['item_id']));
    $pms_name = htmlspecialchars(trim($_POST['pms_name']));
    $pms_description = htmlspecialchars(trim($_POST['pms_description']));
    $frequency = htmlspecialchars(trim($_POST['frequency']));
    $start_schedule = htmlspecialchars(trim($_POST['start_schedule']));
    $end_schedule = htmlspecialchars(trim($_POST['end_schedule']));
    $assigned_to = htmlspecialchars(trim($_POST['assigned_to']));
    $interval = 0;

    // Validate inputs
    if (empty($item_id) || empty($pms_name) || empty($pms_description) || empty($frequency) || empty($start_schedule) || empty($end_schedule) || empty($assigned_to)) {
        echo json_encode([
            "status" => "error",
            "message" => "All fields are required!"
        ]);
        exit;
    }

    // Frequency and interval logic
    switch ($frequency) {
        case 'annually':
            $frequency = "yearly";
            $interval = 1; // 12 months for yearly
            break;
        case 'yearly':
            $frequency = "yearly";
            $interval = 1; // 12 months for yearly
            break;
        case 'semiannually':
            $frequency = "monthly"; // Semiannually runs as monthly with 6-month intervals
            $interval = 6;
            break;
        case 'quarterly':
            $frequency = "monthly"; // Quarterly runs as monthly with 3-month intervals
            $interval = 3;
            break;
        case 'bimonthly':
            $frequency = "monthly"; // Bimonthly runs as monthly with 2-month intervals
            $interval = 2;
            break;
        case 'monthly':
            $frequency = "monthly";
            $interval = 1; // 1 month for monthly
            break;
        case 'weekly':
            $frequency = "weekly";
            $interval = 1; // Approx 1 week (considering weeks in a month)
            break;
        default:
            echo json_encode([
                "status" => "error",
                "message" => "Invalid frequency selected!"
            ]);
            exit;
    }

    // Prepare SQL query to insert data into the database, including description, frequency, and interval
    $query = "INSERT INTO pms (pms_name, pms_description, item_id, frequency, freq_interval, start_schedule, end_schedule, assigned_to,plan_id) 
              VALUES (?, ?, ?, ?, ?, ?, ?, ?,?)";

    if ($stmt = $conn1->prepare($query)) {
        // Bind parameters to the SQL query
        $stmt->bind_param("ssisissii", $pms_name, $pms_description, $item_id, $frequency, $interval, $start_schedule, $end_schedule, $assigned_to,$plan_id);

        // Execute the query
        if ($stmt->execute()) {
            $pms_id = $conn1->insert_id;
            // Prepare the task insertion query
            $task_query = "INSERT INTO pms_tasks(plan_id,pms_id) VALUES (?,?)";

            // Prepare the statement
            $check_stmt = $conn1->prepare($task_query);
            
            // Bind the plan_id to the query
            $check_stmt->bind_param('ii', $plan_id, $pms_id);
            
            // Execute the query
            $check_stmt->execute();
            
            // Close the statement
            $check_stmt->close();

            
            echo json_encode([
                "status" => "success",
                "message" => "PMS added successfully!"
            ]);
        } else {
            echo json_encode([
                "status" => "error",
                "message" => "Error: " . $stmt->error
            ]);
        }

        // Close the statement
        $stmt->close();
    } else {
        echo json_encode([
            "status" => "error",
            "message" => "Error: " . $conn1->error
        ]);
    }
} else {
    echo json_encode([
        "status" => "error",
        "message" => "Invalid request method!"
    ]);
}
?>
