<?php
// Include your database connection file
include('../../database/dbcon.php'); // Adjust the path as needed

// Check if the necessary POST data is set
if (isset($_POST['id']) && isset($_POST['questions'])) {
    // Retrieve the checklist ID and questions array from the POST request
    $id = $_POST['id']; // Checklist ID
    $questions = $_POST['questions']; // Array of questions

    // Check if the ID is not empty and the questions array is not empty
    if (!empty($id) && !empty($questions) ) {
        // Begin transaction
        $conn1->begin_transaction();

        try {
            // Step 1: Delete existing questions for the given pms_id
            $deleteQuery = "DELETE FROM pms_questions WHERE pms_id = ?";
            $deleteStmt = $conn1->prepare($deleteQuery);
            if ($deleteStmt) {
                $deleteStmt->bind_param('i', $id); // Bind 'id' as an integer
                $deleteStmt->execute();
                $deleteStmt->close();
            } else {
                throw new Exception('Failed to prepare delete statement: ' . $conn1->error);
            }

            // Step 2: Insert new questions
            $insertQuery = "INSERT INTO pms_questions (pms_id, questions) VALUES (?, ?)";
            $insertStmt = $conn1->prepare($insertQuery);

            if ($insertStmt) {
                // Bind parameters and execute the statement for each question
                foreach ($questions as $question) {
                    if (!empty(trim($question))) {
                        $sanitized_question = trim($question); // Trim whitespace
                        $insertStmt->bind_param('is', $id, $sanitized_question); // Bind 'id' as integer, 'questions' as string

                        // Execute the statement and check for errors
                        if (!$insertStmt->execute()) {
                            throw new Exception('Failed to insert question: ' . $insertStmt->error);
                        }
                    }
                }

                // Close the prepared statement
                $insertStmt->close();

                // Commit the transaction
                $conn1->commit();

                echo 'Yes'; // All questions inserted successfully
            } else {
                throw new Exception('Failed to prepare insert statement: ' . $conn1->error);
            }

        } catch (Exception $e) {
            // Rollback transaction on error
            $conn1->rollback();
            echo 'Error: ' . $e->getMessage();
        }
    } else {
        echo 'Invalid input. Checklist ID or questions array is missing or invalid.';
    }
} else {
    echo 'Invalid request. Required data not received.';
}

// Close the database connection
$conn1->close();
?>
