<?php
require_once('../../database/dbcon.php');
session_start();

// Set content type to JSON
header('Content-Type: application/json');

// Check if the request method is POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve and sanitize input data
    $id = htmlspecialchars(trim($_POST['id'])); // ID of the PMS entry to update
    $item_id = htmlspecialchars(trim($_POST['item_id']));
    $pms_name = htmlspecialchars(trim($_POST['pms_name']));
    $pms_description = htmlspecialchars(trim($_POST['pms_description']));
    $frequency = htmlspecialchars(trim($_POST['frequency']));
    $start_schedule = htmlspecialchars(trim($_POST['start_schedule']));
    $end_schedule = htmlspecialchars(trim($_POST['end_schedule']));
    $assigned_to = htmlspecialchars(trim($_POST['assigned_to']));
    $interval = 0;

    // Validate inputs
    if (empty($id) || empty($item_id) || empty($pms_name) || empty($pms_description) || empty($frequency) || empty($start_schedule) || empty($end_schedule) || empty($assigned_to)) {
        echo json_encode([
            "status" => "error",
            "message" => "All fields are required!"
        ]);
        exit;
    }

    // Frequency and interval logic
    switch ($frequency) {
        case 'annually':
            $frequency = "yearly";
            $interval = 1; // 12 months for yearly
            break;
        case 'yearly':
            $frequency = "yearly";
            $interval = 1; // 12 months for yearly
            break;
        case 'semiannually':
            $frequency = "monthly";
            $interval = 6; // 6 months
            break;
        case 'quarterly':
            $frequency = "monthly";
            $interval = 3; // 3 months
            break;
        case 'bimonthly':
            $frequency = "monthly";
            $interval = 2; // 2 months
            break;
        case 'monthly':
            $frequency = "monthly";
            $interval = 1; // 1 month
            break;
        case 'weekly':
            $frequency = "weekly";
            $interval = 1; // 1 week
            break;
        default:
            echo json_encode([
                "status" => "error",
                "message" => "Invalid frequency selected!"
            ]);
            exit;
    }

    // Prepare SQL query to update data in the database
    $query = "UPDATE pms 
              SET pms_name = ?, pms_description = ?, item_id = ?, frequency = ?, freq_interval = ?, start_schedule = ?, end_schedule = ?, assigned_to = ? 
              WHERE id = ?";

    if ($stmt = $conn1->prepare($query)) {
        // Bind parameters to the SQL query
        $stmt->bind_param("ssisissii", $pms_name, $pms_description, $item_id, $frequency, $interval, $start_schedule, $end_schedule, $assigned_to, $id);

        // Execute the query
        if ($stmt->execute()) {
            echo json_encode([
                "status" => "success",
                "message" => "PMS updated successfully!"
            ]);
        } else {
            echo json_encode([
                "status" => "error",
                "message" => "Error: " . $stmt->error
            ]);
        }

        // Close the statement
        $stmt->close();
    } else {
        echo json_encode([
            "status" => "error",
            "message" => "Error: " . $conn1->error
        ]);
    }
} else {
    echo json_encode([
        "status" => "error",
        "message" => "Invalid request method!"
    ]);
}
?>
