<?php
require_once('../../database/dbcon.php');
ob_start();
session_start();

function respond($status, $message)
{
    echo json_encode(["status" => $status, "message" => $message]);
    exit;
}

if (isset($_POST['requested_by'])) {
    $submit_request_to = $_POST['submit_request_to'];
    $equipment_problem = $_POST['equipment_problem'];
    $requested_by = $_POST['requested_by'];
    $property_codes = $_POST['property_code']; // Array of property codes
    $department_id = $_SESSION['department_id'];
    $currYear = date("Y");

    // Basic form validation
    if (empty($equipment_problem) || empty($requested_by) || empty($property_codes) || empty($submit_request_to)) {
        respond("error", "All fields are required.");
    }

    // Initialize a flag to check if any insertion/update was successful
    $operationSuccess = false;

    foreach ($property_codes as $property_code) {
        // Explode the property code by '-'
        // Assuming you have a database connection $conn

        $explodedPropertyCode = explode('-', $property_code);
        $category_code = isset($explodedPropertyCode[0]) ? $explodedPropertyCode[0] : '';
        $code_id = isset($explodedPropertyCode[1]) ? $explodedPropertyCode[1] : '';

        // Check if the exploded values are valid
        if (empty($category_code) || empty($code_id)) {
            respond("error", "Invalid property code format for code: $property_code.");
            continue;
        }

        // Strip leading zeroes from code_id
        $code_id = ltrim($code_id, '0');

        // Retrieve category ID based on the category code
        $catStmt = $conn1->prepare("SELECT id FROM categories WHERE code = ?");
        $catStmt->bind_param("s", $category_code);
        $catStmt->execute();
        $catStmt->bind_result($category_id);
        $catStmt->fetch();
        $catStmt->close();

        // Check if the code exists in the items table
        $sql = "SELECT COUNT(*) FROM items WHERE category_id = ? AND code_id = ?";
        $stmt = $conn1->prepare($sql);
        $stmt->bind_param("ii", $category_id, $code_id);
        $stmt->execute();
        $stmt->bind_result($count);
        $stmt->fetch();
        $stmt->close();

        // If the item does not exist, handle the error
        if ($count == 0) {
            respond("error", "The item with property code $category_id $code_id does not exist.");
            continue;
        }

        // Get the total number of rows and the last code1_id and year of the date_requested for the specific department_id
        $result = $conn1->prepare("
            SELECT COUNT(*) as total_rows, MAX(code1_id) as last_code1_id, MAX(YEAR(date_requested)) as last_year 
            FROM status_report_1 
            WHERE department_id = ?
        ");
        $result->bind_param("i", $department_id);
        $result->execute();
        $result->bind_result($total_rows, $last_code1_id, $last_year);
        $result->fetch();
        $result->close();

        // Calculate the new code1_id
        if ($currYear > $last_year) {
            $code1_id = 1;
        } else {
            $code1_id = max($total_rows + 1, $last_code1_id + 1);
        }

        // Prepare an SQL statement for inserting or updating into status_report_1
        $sql = "INSERT INTO status_report_1 (code1_id, equipment_problem, requested_by, department_id, category_id, code_id, submit_request_to) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
            ON DUPLICATE KEY UPDATE
                code1_id = VALUES(code1_id),
                equipment_problem = VALUES(equipment_problem), 
                requested_by = VALUES(requested_by), 
                department_id = VALUES(department_id), 
                category_id = VALUES(category_id)";

        $stmt = $conn1->prepare($sql);
        $stmt->bind_param("isiiiii", $code1_id, $equipment_problem, $requested_by, $department_id, $category_id, $code_id, $submit_request_to);
        $stmt->execute();

        if ($stmt->affected_rows > 0) {
            $operationSuccess = true;

            // Get last inserted or updated ID
            $last_id = $stmt->insert_id > 0 ? $stmt->insert_id : null;

            if (!empty($last_id)) {
                // Fetch the existing ID if an update occurred
                $select_sql = "SELECT id FROM status_report_1 WHERE code1_id = ? AND requested_by = ? AND department_id = ? AND submit_request_to = ?";
                $select_stmt = $conn1->prepare($select_sql);
                $select_stmt->bind_param("iiii", $code1_id, $requested_by, $department_id, $submit_request_to);
                $select_stmt->execute();
                $select_stmt->bind_result($last_id);
                $select_stmt->fetch();
                $select_stmt->close();
            } else {
                $operationSuccess = false;
                $itemFailure = true;
            }

            // Insert notification for each property code
            $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
            $content = "sent a status report for property code $property_code.";
            $notification_sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
                VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
                ON DUPLICATE KEY UPDATE
                timestamp = CURRENT_TIMESTAMP";

            $stmt2 = $conn1->prepare($notification_sql);
            $stmt2->bind_param("iiis", $sender_id, $last_id, $submit_request_to, $content);
            $result2 = $stmt2->execute();

            if (!$result2) {
                respond("error", "Error while inserting notification for $property_code: " . $stmt2->error);
            }

            $stmt2->close();
        } else {
            respond("error", "Error with $property_code: " . $stmt->error);
        }

        $stmt->close();
    }

    if ($operationSuccess) {
        respond("success", " $last_id ");
    } else {
        if ($itemFailure) {
            respond("error", "$last_id");
        } else {
            respond("error", "No status report was created.");
        }
    }

    $conn1->close();
}



if (isset($_POST['recommended_by'])) {
    $status_report_id = $_POST['status_report_id'];
    $equipment_repair = $_POST['equipment_repair'];
    $type_of_repair = $_POST['type_of_repair'];
    $recommended_by = $_POST['recommended_by'];

    $sql = "INSERT INTO status_report_2 (status_report_id, equipment_repair, type_of_repair, recommended_by) 
            VALUES (?, ?, ?, ?)
            ON DUPLICATE KEY UPDATE
            equipment_repair = VALUES(equipment_repair), type_of_repair = VALUES(type_of_repair), 
            recommended_by = VALUES(recommended_by)";

    $stmt = $conn1->prepare($sql);
    $stmt->bind_param("issi", $status_report_id, $equipment_repair, $type_of_repair, $recommended_by);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        // Additional logic after getting the ID
        $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
        $department_id = $_SESSION['department_id']; // Assuming you have the sender_id in the session

        $content = "requested a job order.";
        $sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
                    VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
                    ON DUPLICATE KEY UPDATE
                    timestamp = CURRENT_TIMESTAMP";

        $stmt2 = $conn1->prepare($sql);
        $stmt2->bind_param("iiis", $sender_id, $status_report_id, $department_id, $content);
        $result = $stmt2->execute();

        if ($result) {
            respond("success", "Job order created or updated successfully.");
        } else {
            respond("error", "Error while inserting notification: " . $stmt2->error);
        }
    } else {
        respond("error", "Error: " . $stmt->error);
    }

    $stmt->close();
    $conn1->close();
}

if (isset($_POST['approved_by'])) {
    $status_report_id = $_POST['status_report_id'];
    $depthead_comment = $_POST['depthead_comment'];
    $approval = $_POST['approval'];
    $approved_by = $_POST['approved_by'];

    $sql = "INSERT INTO status_report_3 (status_report_id, depthead_comment, approval, approved_by) 
            VALUES (?, ?, ?, ?)
            ON DUPLICATE KEY UPDATE
            depthead_comment = VALUES(depthead_comment), approval = VALUES(approval), 
            approved_by = VALUES(approved_by)";

    $stmt = $conn1->prepare($sql);
    $stmt->bind_param("issi", $status_report_id, $depthead_comment, $approval, $approved_by);
    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        // Additional logic after getting the ID
        $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
        $department_id = $_SESSION['department_id']; // Assuming you have the sender_id in the session

        $content = "approved a job order.";
        $sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
                    VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
                    ON DUPLICATE KEY UPDATE
                    timestamp = CURRENT_TIMESTAMP";

        $stmt2 = $conn1->prepare($sql);
        $stmt2->bind_param("iiis", $sender_id, $status_report_id, $department_id, $content);
        $result = $stmt2->execute();

        if ($result) {
            respond("success", "Approval created or updated successfully.");
        } else {
            respond("error", "Error while inserting notification: " . $stmt2->error);
        }
    } else {
        respond("error", "Error: " . $stmt->error);
    }

    $stmt->close();
    $conn1->close();
}

if (isset($_POST['completed_by'])) {
    $status_report_id = $_POST['status_report_id'];
    $job_order = $_POST['job_order'];
    $outcome = $_POST['outcome'];
    $completed_by = $_POST['completed_by'];

    $target_dir_photo = "../../resources/img/photo_equipment/";
    $target_dir_report = "../../resources/img/service_report/";

    // Handle photo equipment upload
    if (isset($_FILES["photo_equipment"])) {
        $photo_equipment = $_FILES["photo_equipment"];
        $photo_equipment_path = $target_dir_photo . basename($photo_equipment["name"]);
        if (!move_uploaded_file($photo_equipment["tmp_name"], $photo_equipment_path)) {

            if ($_POST['photo_equipment']) {
                $photo_equipment_path = $_POST['photo_equipment'];
            } else {
                $photo_equipment_path = NULL;
            }
        }
    } else {
        if ($_POST['photo_equipment']) {
            $photo_equipment_path = $_POST['photo_equipment'];
        } else {
            $photo_equipment_path = NULL;
        }
    }

    // Handle service report upload
    if (isset($_FILES["service_report"])) {
        $service_report = $_FILES["service_report"];
        $service_report_path = $target_dir_report . basename($service_report["name"]);
        if (!move_uploaded_file($service_report["tmp_name"], $service_report_path)) {
            if (isset($_POST['service_report'])) {
                $service_report_path = $_POST['service_report'];
            } else {
                $service_report_path = NULL;
            }
        }
    } else {
        if (isset($_POST['service_report'])) {
            $service_report_path = $_POST['service_report'];
        } else {
            $service_report_path = NULL;
        }
    }

    // Prepare an SQL statement for inserting into status_report_3
    $sql = "INSERT INTO status_report_4 (status_report_id, job_order, outcome, photo_equipment, service_report, completed_by) 
    VALUES (?, ?, ?, ?, ?, ?)
    ON DUPLICATE KEY UPDATE
    job_order = VALUES(job_order), 
    outcome = VALUES(outcome), 
    photo_equipment = VALUES(photo_equipment), 
    service_report = VALUES(service_report), 
    completed_by = VALUES(completed_by)";

    // Prepare the statement
    if ($stmt = $conn1->prepare($sql)) {
        // Bind parameters
        $stmt->bind_param("issssi", $status_report_id, $job_order, $outcome, $photo_equipment_path, $service_report_path, $completed_by);

        // Execute the statement
        $stmt->execute();

        // Check if the insert was successful
        if ($stmt->affected_rows > 0) {
            // Additional logic after getting the ID
            $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
            $department_id = $_SESSION['department_id']; // Assuming you have the sender_id in the session

            $content = "reported the outcome of repair/maintenance.";
            $sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
                    VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
                    ON DUPLICATE KEY UPDATE
                    timestamp = CURRENT_TIMESTAMP";

            $stmt2 = $conn1->prepare($sql);
            $stmt2->bind_param("iiis", $sender_id, $status_report_id, $department_id, $content);
            $result = $stmt2->execute();

            if ($result) {
                respond("success", "Job order created successfully.");
            } else {
                respond("error", "Error while inserting notification: " . $stmt2->error);
            }
            // echo "
            // <script>
            //     alert('Job order created successfully.');
            //     history.go(-1);
            // </script>
            // ";
        }
        // else {
        //     // Additional logic after getting the ID
        //     $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
        //     $department_id = $_SESSION['department_id']; // Assuming you have the sender_id in the session

        //     $content = "evaluated the status report.";
        //     $sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
        //                         VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
        //                         ON DUPLICATE KEY UPDATE
        //                         timestamp = CURRENT_TIMESTAMP";

        //     $stmt2 = $conn1->prepare($sql);
        //     $stmt2->bind_param("iiis", $sender_id, $status_report_id, $department_id, $content);
        //     $result = $stmt2->execute();

        //     if ($result) {
        //         respond("success", "Job order updated successfully.");
        //     } else {
        //         respond("error", "Error while inserting notification: " . $stmt2->error);
        //     }
        //     // echo "
        //     // <script>
        //     //     alert('Job order updated successfully.');
        //     //     history.go(-1);
        //     // </script>
        //     // ";
        // }

        // Close the statement
        $stmt->close();
    } else {
        respond("error", "Error: " . $conn1->error);

        // echo "
        // <script>
        //     alert('Error preparing statement: $conn1->error');
        //     history.go(-1);
        // </script>
        // ";
    }

    // Close the connection
    $conn1->close();
}

if ((isset($_POST['repair_effectiveness']) && !empty($_POST['repair_effectiveness']))
    || (isset($_POST['status']) && !empty($_POST['status']))
) {
    $status_report_id = $_POST['status_report_id'];
    $repair_effectiveness = isset($_POST['repair_effectiveness']) ? $_POST['repair_effectiveness'] : "";
    $action = isset($_POST['action']) ? $_POST['action'] : "";
    $status = isset($_POST['status']) ? $_POST['status'] : "";

    if ($_SESSION['privilege'] == "DEPARTMENT HEAD") {
        $sql = "INSERT INTO status_report_5 (status_report_id, repair_effectiveness, action) 
                VALUES (?, ?, ?)
                ON DUPLICATE KEY UPDATE
                repair_effectiveness = VALUES(repair_effectiveness)";

        $stmt = $conn1->prepare($sql);
        $stmt->bind_param("iss", $status_report_id, $repair_effectiveness, $action);
        $content = "evaluated a status report.";
    } else {
        $sql = "INSERT INTO status_report_5 (status_report_id, status) 
                VALUES (?, ?)
                ON DUPLICATE KEY UPDATE
                status = VALUES(status)";

        $stmt = $conn1->prepare($sql);
        $stmt->bind_param("is", $status_report_id, $status);
        $content = "evaluated a status report.";
    }

    $stmt->execute();

    if ($stmt->affected_rows > 0) {
        $sender_id = $_SESSION['id']; // Assuming you have the sender_id in the session
        $department_id = $_SESSION['department_id']; // Assuming you have the sender_id in the session

        $sql = "INSERT INTO notification_records (sender_id, status_report_id, department_id, content, link)
                            VALUES (?, ?, ?, ?, 'status_report.php?form_control_no=')
                            ON DUPLICATE KEY UPDATE
                            timestamp = CURRENT_TIMESTAMP";

        $stmt2 = $conn1->prepare($sql);
        $stmt2->bind_param("iiis", $sender_id, $status_report_id, $department_id, $content);
        $result = $stmt2->execute();

        if ($result) {
            respond("success", "Evaluation created/updated successfully.");
        } else {
            respond("error", "Error while inserting notification: " . $stmt2->error);
        }
    } else {
        respond("error", "Error: " . $stmt->error);
    }

    $stmt->close();
    $conn1->close();
}
