<?php
require_once('../../database/dbcon.php');
session_start();

// Set content type to JSON
header('Content-Type: application/json');

// Check if the request method is POST
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // Retrieve and sanitize input data
    $report_id = htmlspecialchars(trim($_POST['report_id']));
    $category = htmlspecialchars(trim($_POST['category']));
    $department_id = htmlspecialchars(trim($_POST['department']));
    $location = htmlspecialchars(trim($_POST['location']));
    $details = htmlspecialchars(trim($_POST['details']));
    $status = htmlspecialchars(trim($_POST['status']));
    $completion_date = htmlspecialchars(trim($_POST['completion_date']));
    $remarks = htmlspecialchars(trim($_POST['remarks']));

    // Validate inputs
    if (empty($category) || empty($department_id) || empty($location) || empty($details) || empty($status) || empty($completion_date)) {
        echo json_encode([
            "status" => "error",
            "message" => "All fields are required!"
        ]);
        exit;
    }

    // Prepare SQL query to update data in the database
    $query = "UPDATE weekly_report SET category=?, department_id=?, location=?, details=?, status=?, completion_date=?, remarks=? WHERE id=?";
    
    if ($stmt = $conn1->prepare($query)) {
        // Bind parameters to the SQL query
        $stmt->bind_param("sisssssi", $category, $department_id, $location, $details, $status, $completion_date, $remarks, $report_id);

        // Execute the query
        if ($stmt->execute()) {
            echo json_encode([
                "status" => "success",
                "message" => "Weekly report updated successfully!"
            ]);
        } else {
            echo json_encode([
                "status" => "error",
                "message" => "Error: " . $stmt->error
            ]);
        }

        // Close the statement
        $stmt->close();
    } else {
        echo json_encode([
            "status" => "error",
            "message" => "Error: " . $conn1->error
        ]);
    }
} else {
    echo json_encode([
        "status" => "error",
        "message" => "Invalid request method!"
    ]);
}
?>
