<?php
require("../../resources/lib/fpdf186/fpdf.php"); // Include FPDF library

include('../../database/dbcon.php'); // Include the database connection

function convertDate($dateString, $dateType)
{
    $date = DateTime::createFromFormat('Y-m-d', $dateString);
    if ($dateType == 1) {
        return $date->format('M. j, Y');
    } else if ($dateType == 2) {
        return $date->format('M. j');
    }
}

class AlphaPDF extends FPDF
{
    protected $extgstates = array();

    function SetAlpha($alpha, $bm = 'Normal')
    {
        $gs = $this->AddExtGState(array('ca' => $alpha, 'CA' => $alpha, 'BM' => '/' . $bm));
        $this->SetExtGState($gs);
    }

    function AddExtGState($parms)
    {
        $n = count($this->extgstates) + 1;
        $this->extgstates[$n]['parms'] = $parms;
        return $n;
    }

    function SetExtGState($gs)
    {
        $this->_out(sprintf('/GS%d gs', $gs));
    }

    function _enddoc()
    {
        if (!empty($this->extgstates) && $this->PDFVersion < '1.4')
            $this->PDFVersion = '1.4';
        parent::_enddoc();
    }

    function _putextgstates()
    {
        foreach ($this->extgstates as $k => $extgstate) {
            $this->_newobj();
            $this->extgstates[$k]['n'] = $this->n;
            $this->_put('<</Type /ExtGState');
            $parms = $extgstate['parms'];
            $this->_put(sprintf('/ca %.3F', $parms['ca']));
            $this->_put(sprintf('/CA %.3F', $parms['CA']));
            $this->_put('/BM ' . $parms['BM']);
            $this->_put('>>');
            $this->_put('endobj');
        }
    }

    function _putresourcedict()
    {
        parent::_putresourcedict();
        $this->_put('/ExtGState <<');
        foreach ($this->extgstates as $k => $extgstate)
            $this->_put('/GS' . $k . ' ' . $extgstate['n'] . ' 0 R');
        $this->_put('>>');
    }

    function _putresources()
    {
        $this->_putextgstates();
        parent::_putresources();
    }



    protected $widths;
    protected $aligns;

    function SetWidths($w)
    {
        // Set the array of column widths
        $this->widths = $w;
    }

    function SetAligns($a)
    {
        // Set the array of column alignments
        $this->aligns = $a;
    }

    function Row($data)
    {
        // Calculate the height of the row
        $nb = 0;
        for ($i = 0; $i < count($data); $i++)
            $nb = max($nb, $this->NbLines($this->widths[$i], $data[$i]));
        $h = 5 * $nb;
        // Issue a page break first if needed
        $this->CheckPageBreak($h);
        // Draw the cells of the row
        for ($i = 0; $i < count($data); $i++) {
            $w = $this->widths[$i];
            $a = isset($this->aligns[$i]) ? $this->aligns[$i] : 'L';
            // Save the current position
            $x = $this->GetX();
            $y = $this->GetY();
            // Draw the border
            $this->Rect($x, $y, $w, $h);
            // Print the text
            $this->MultiCell($w, 5, $data[$i], 0, $a);
            // Put the position to the right of the cell
            $this->SetXY($x + $w, $y);
        }
        // Go to the next line
        $this->Ln($h);
    }

    function RowHeader($data)
    {
        $nb = 0;  // Number of lines for the highest cell
        for ($i = 0; $i < count($data); $i++) {
            // Calculate the number of lines needed for each cell
            $nb = max($nb, $this->NbLines($this->widths[$i], $data[$i]));
        }
        $h = 5 * $nb;  // Calculate the row height based on maximum lines

        $this->CheckPageBreak($h);  // Page break if needed

        // Draw the header cells with vertical and horizontal alignment
        for ($i = 0; $i < count($data); $i++) {
            $w = $this->widths[$i];  // Cell width
            $a = 'C';  // Center alignment for both vertical and horizontal

            // Save the current position
            $x = $this->GetX();
            $y = $this->GetY();

            // Draw the border
            $this->Rect($x, $y, $w, $h);

            // Calculate the vertical position to center text in the cell
            $cellHeight = $this->NbLines($w, $data[$i]) * 5;  // Calculate text height
            $yOffset = ($h - $cellHeight) / 2;  // Vertical offset to center text

            // Move to the center vertically
            $this->SetXY($x, $y + $yOffset);

            // Print the text (center horizontally)
            $this->MultiCell($w, 5, $data[$i], 0, $a);

            // Move to the right for the next cell
            $this->SetXY($x + $w, $y);
        }

        // Go to the next line
        $this->Ln($h);
    }

    function CheckPageBreak($h)
    {
        // If the height h would cause an overflow, add a new page immediately
        if ($this->GetY() + $h > $this->PageBreakTrigger)
            $this->AddPage($this->CurOrientation);
    }

    function NbLines($w, $txt)
    {
        // Compute the number of lines a MultiCell of width w will take
        if (!isset($this->CurrentFont))
            $this->Error('No font has been set');
        $cw = $this->CurrentFont['cw'];
        if ($w == 0)
            $w = $this->w - $this->rMargin - $this->x;
        $wmax = ($w - 2 * $this->cMargin) * 1000 / $this->FontSize;
        $s = str_replace("\r", '', (string)$txt);
        $nb = strlen($s);
        if ($nb > 0 && $s[$nb - 1] == "\n")
            $nb--;
        $sep = -1;
        $i = 0;
        $j = 0;
        $l = 0;
        $nl = 1;
        while ($i < $nb) {
            $c = $s[$i];
            if ($c == "\n") {
                $i++;
                $sep = -1;
                $j = $i;
                $l = 0;
                $nl++;
                continue;
            }
            if ($c == ' ')
                $sep = $i;
            $l += $cw[$c];
            if ($l > $wmax) {
                if ($sep == -1) {
                    if ($i == $j)
                        $i++;
                } else
                    $i = $sep + 1;
                $sep = -1;
                $j = $i;
                $l = 0;
                $nl++;
            } else
                $i++;
        }
        return $nl;
    }
}

class PDFReport extends AlphaPDF
{
    private $columnWidths = [];
    private $ongoingColumnWidths = [];

    function Header()
    {
        // Path to the image
        $imagePath = '../../resources/img/compass-main-logo.png';
        if (file_exists($imagePath)) {
            $this->Image($imagePath, 5, 10, 50); // Add image
        } else {
            $this->SetFont('Arial', 'B', 10);
            $this->SetXY(10, 10);
            $this->Cell(0, 10, "Logo not found", 0, 1, 'L');
        }

        // Document info
        $this->SetFont('Arial', 'I', 5);
        $this->SetXY(228, 10);
        $this->MultiCell(60, 2.5, "Doc ID: _________\nRevision No. ____\nDate Approved: __________________\nInternal", 0, 'R');

        // Title
        $this->SetFont('Arial', 'B', 10);
        $this->SetXY(10, 20);
        $this->Cell(0, 10, "MAINTENANCE WEEKLY COMPLETION REPORT", 0, 1, 'C');

        // Add a colored line below the header
        $this->SetXY(10, 30); // Position for the line
        $this->SetFillColor(0, 176, 240); // Set color (RGB: 00B0F0)
        $this->Cell(0, 0.2, '', 0, 1, 'C', true); // Add colored line
        $this->Ln(); // Move to the next line

        // Add margin below the header
        $this->SetY($this->GetY() + 5); // Adjust the value as needed to set the margin
    }


    // Add header and design elements for a specific department
    function addDesignElements($departmentName, $coveredDate)
    {
        $this->SetFont('Arial', 'B', 10);
        $this->SetTextColor(0, 0, 0);
        $this->Cell(0, 10, "Covered Period: " . $coveredDate, 0, 1, 'L');

        $pageWidth = 297 - 20;
        $this->columnWidths = $this->calculateColumnWidths($pageWidth, 6);
        $this->ongoingColumnWidths = $this->calculateOngoingColumnWidths($pageWidth, 6);

        $this->SetFont('Arial', 'B', 10);
        $this->SetFillColor(0, 32, 96);
        $this->SetTextColor(255, 255, 255);
        $this->Cell($pageWidth, 10, strtoupper($departmentName), 1, 1, 'C', true);
        $this->SetTextColor(0, 0, 0);

        $headers = [' ', 'CATEGORY', 'LOCATION', 'DETAILS', 'STATUS', "COMPLETION\nDATE", 'REMARKS'];
        $this->SetFont('Arial', 'B', 10);
        $this->SetFillColor(255, 255, 255);
        $this->SetWidths(array(7, 30, 45, 100, 22, 28, 45));
        $this->RowHeader($headers);
    }


    // Add table rows with data
    function addTableData($records)
    {
        $this->SetFont('Arial', '', 10);
        $index = 1;  // Initialize the index counter

        foreach ($records as $data) {
            if (strtolower($data['status'] ?? '') == "done") {
                $this->SetWidths(array(7, 30, 45, 100, 22, 28, 45));  // Set column widths

                // Add the index as the first element in the Row array
                $this->Row(array(
                    $index,  // Add the index
                    $data['category'],
                    $data['department'],
                    $data['details'],
                    strtoupper($data['status']),
                    $data['completion_date'],
                    $data['remarks']
                ));

                $index++;  // Increment the index for the next row
            }
        }
    }

    // Add ongoing data table
    function addOngoingData($records)
    {
        if (empty($records)) {
            return;
        }

        $this->AddPage();
        $this->SetFont('Arial', 'B', 10);
        $this->SetFillColor(166, 166, 166);
        $this->SetTextColor(0, 0, 0);
        $this->Cell(array_sum($this->ongoingColumnWidths), 7, 'ONGOING TASKS', 1, 1, 'C', true);
        $this->SetTextColor(0, 0, 0);

        $headers = [' ', 'CATEGORY', 'DEPARTMENT', 'DETAILS', 'STATUS', "TARGET COMPLETION\nDATE", 'REMARKS'];
        $this->SetFont('Arial', 'B', 10);
        $this->SetFillColor(255, 255, 255);
        $this->SetWidths(array(7, 30, 45, 100, 22, 28, 45));
        $this->RowHeader($headers);

        $this->SetFont('Arial', '', 10);
        $index = 1;  // Initialize the index counter

        foreach ($records as $data) {
            if (strtolower($data['status'] ?? '') == "ongoing") {
                $this->SetWidths(array(7, 30, 45, 100, 22, 28, 45));  // Set column widths

                // Add the index as the first element in the Row array
                $this->Row(array(
                    $index,  // Add the index
                    $data['category'],
                    $data['department'],
                    $data['details'],
                    strtoupper($data['status']),
                    $data['completion_date'],
                    $data['remarks']
                ));

                $index++;  // Increment the index for the next row
            }
        }
    }

    function calculateColumnWidths($totalWidth, $columns)
    {
        $baseWidth = $totalWidth / $columns;
        $columnWidths = array_fill(0, $columns, $baseWidth);

        $extraWidth = 355;
        $decreaseWidth = 255;

        $columnWidths[2] += $extraWidth;
        $columnWidths[0] -= $decreaseWidth;

        $totalCalculatedWidth = array_sum($columnWidths);

        if ($totalCalculatedWidth > $totalWidth) {
            $excessWidth = $totalCalculatedWidth - $totalWidth;
            $columnWidths[4] -= $excessWidth;
        }

        return $columnWidths;
    }

    function calculateOngoingColumnWidths($totalWidth, $columns)
    {
        $baseWidth = $totalWidth / $columns;
        $columnWidths = array_fill(0, $columns, $baseWidth);

        $extraWidth = 15;
        $decreaseWidth = 5;

        $columnWidths[4] += $extraWidth;
        $columnWidths[3] -= $decreaseWidth;

        $totalCalculatedWidth = array_sum($columnWidths);

        if ($totalCalculatedWidth > $totalWidth) {
            $excessWidth = $totalCalculatedWidth - $totalWidth;
            $columnWidths[4] -= $excessWidth;
        }

        return $columnWidths;
    }

    function Footer()
    {
        // Draw the watermark image
        $this->AddWatermark();

        // Add page number on top of the watermark
        $this->SetY($this->GetPageHeight() - 15);
        $this->SetFont('Arial', 'I', 8);
        $this->Cell(0, 10, 'Page ' . $this->PageNo(), 0, 0, 'C');
    }

    // Method to add watermark image
    function AddWatermark()
    {
        $pageWidth = $this->GetPageWidth();
        $pageHeight = $this->GetPageHeight();
        $footerImagePath = '../../resources/img/footer-logo-removebg.png';

        $imageWidth = 75;
        $imageHeight = 75;

        if (file_exists($footerImagePath)) {
            $this->SetAlpha(0.3); // Set alpha for watermark effect

            // Position the image in the bottom right corner
            $this->Image(
                $footerImagePath,
                $pageWidth - $imageWidth, // X position (right margin)
                $pageHeight - $imageHeight, // Y position (bottom margin)
                $imageWidth,
                $imageHeight,
                '',
                '',
                'T',
                false,
                300,
                '',
                false,
                false,
                0,
                'CM',
                false,
                false
            );

            $this->SetAlpha(1); // Reset alpha to default
        }
    }
}

// Create new PDF object with landscape orientation
$pdf = new PDFReport('L', 'mm', 'A4'); // 'L' for landscape orientation

// Get the query from the URL parameter and validate it
if (isset($_GET['empQuery']) && !empty($_GET['empQuery'])) {
    $empQuery = $_GET['empQuery'];
    $empRecords = $conn1->query($empQuery);
    if (!$empRecords) {
        echo "<script>alert('Error executing query: " . $conn1->error . "');</script>";
        exit;
    }
} else {
    echo "<script>alert('Query parameter is missing or empty.');</script>";
    exit;
}

// Group records by department and collect ongoing tasks
$departmentData = [];
$ongoingTasks = [];
while ($data = $empRecords->fetch_assoc()) {
    $department = $data['department'];
    if (!isset($departmentData[$department])) {
        $departmentData[$department] = [];
    }
    $departmentData[$department][] = $data;

    // Collect ongoing tasks
    if (strtolower($data['status']) == 'ongoing') {
        $ongoingTasks[] = $data;
    }
}

// Generate the PDF
foreach ($departmentData as $departmentName => $records) {
    // Skip departments with only one ongoing record
    if (intval(count($records)) >= 1 && strtolower($records[0]['status']) == 'ongoing') {
        continue;
    } else {

        $pdf->AddPage(); // Only add pages here as needed for each department

        // Determine covered period
        if ((isset($_GET['start_date']) && !empty($_GET['start_date'])) && (isset($_GET['end_date']) && !empty($_GET['end_date']))) {
            $date1 = new DateTime($_GET['start_date']);
            $date2 = new DateTime($_GET['end_date']);
            if ($date1->format("W") == $date2->format("W")) {
                $weekNumber = $date1->format("W");
            } else {
                $weekNumber = $date1->format("W") . " - " . $date2->format("W");
            }
            $coveredDate = "Week " . $weekNumber . " (" . convertDate($_GET['start_date'], 2) . " - " . convertDate($_GET['end_date'], 1) . ")";
        } else if (isset($_GET['start_date']) && !empty($_GET['start_date'])) {
            $date1 = new DateTime($_GET['start_date']);
            $weekNumber = $date1->format("W");
            $coveredDate = "Week " . $weekNumber . " (" . convertDate($_GET['start_date'], 1) . " - " . ")";
        } else if (isset($_GET['end_date']) && !empty($_GET['end_date'])) {
            $date2 = new DateTime($_GET['end_date']);
            $weekNumber = $date2->format("W");
            $coveredDate = "Week " . $weekNumber . " (" . " - " . convertDate($_GET['end_date'], 1) . ")";
        } else {
            $coveredDate = "All Time";
        }

        $pdf->addDesignElements($departmentName, $coveredDate); // Add design elements
        $pdf->addTableData($records); // Add table data
    }
}

// Add Ongoing Tasks Table if there are any ongoing tasks
if (!empty($ongoingTasks)) {
    $pdf->addOngoingData($ongoingTasks); // Add ongoing tasks data
}

// Output the PDF
$pdf->Output('Maintenance Weekly Completion Report - ' . $coveredDate . '.pdf', 'I'); // Output to the browser
