<?php
require 'vendor/autoload.php';

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;

include('../../database/dbcon.php');

function find_all($db, $table) {
    global $conn1, $conn2;
    $conn = ($db === "conn1") ? $conn1 : $conn2;

    $query = ($table == "items") ? "SELECT * FROM " . $table . " ORDER BY id DESC LIMIT 150" : "SELECT * FROM " . $table;
    $result = $conn->query($query);

    return ($result->num_rows > 0) ? mysqli_fetch_all($result, MYSQLI_ASSOC) : null;
}

// Function to find records from two tables
function find_from2tables($db, $table1, $table2, $foreign, $primary) {
    global $conn1, $conn2;
    $conn = ($db === "conn1") ? $conn1 : $conn2;

    $query = "SELECT * FROM " . $table1 . " INNER JOIN " . $table2 . " ON " . $table1 . "." . $foreign . " = " . $table2 . "." . $primary;
    $result = $conn->query($query);

    return ($result->num_rows > 0) ? mysqli_fetch_all($result, MYSQLI_ASSOC) : null;
}

// Create new Spreadsheet object
$spreadsheet = new Spreadsheet();
$sheet = $spreadsheet->getActiveSheet();
// Get the highest row number and column letter referenced in the worksheet
$highestRow = $sheet->getHighestDataRow(); // e.g. 10
$highestColumn = $sheet->getHighestDataColumn(); // e.g 'F'


// Add image to the top left corner
$drawing = new Drawing();
$drawing->setPath('../img/compass-main-logo.png'); // Path to your image file
$drawing->setCoordinates('A1');
$drawing->setOffsetX(-15);
$drawing->setOffsetY(-20);

$drawing->setWidthAndHeight(450, 150); // Set the desired width and height of the image
$drawing->setWorksheet($sheet);

// Adjust row heights to fit the logo
$sheet->getRowDimension('1')->setRowHeight(10);
$sheet->getRowDimension('2')->setRowHeight(10);
$sheet->getRowDimension('3')->setRowHeight(10);
$sheet->getRowDimension('4')->setRowHeight(10);

// Add document details to the top right corner
// Document details as a string
$details = "Doc ID: PAM-01F1\nRevision No.: 0\nDate Approved: 10-May-2024\nInternal";

// Splitting the string into lines
$lines = explode("\n", $details);

// Print the lines line by line
$lineIndex = 1; // Start index for lines
for ($i = 0; $i < 4; ++$i) {
    $sheet->setCellValue('P' . $lineIndex, $lines[$i]);
    $sheet->getStyle('P' . $lineIndex)->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_RIGHT);
    $sheet->getStyle('P' . $lineIndex)->getFont()->setItalic(true)->setSize(8); // Adjust font size to 8
    $lineIndex++;
}
// Add an empty row for spacing
$sheet->insertNewRowBefore(7, 3); // Insert three empty rows starting from row 4



// Merge cells for the title
$sheet->mergeCells('A6:P6'); // Merge cells for the title starting from row 6
$sheet->setCellValue('A6', 'Inventory' . "\n " . 'List'); // Set the title starting from row 6

// Style the title
$sheet->getStyle('A6')->getFont()->setBold(true)->setSize(14);
$sheet->getStyle('A6')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);

// Add a border under the title with specific color
$sheet->getStyle('A6:P6')->getBorders()->getBottom()->setBorderStyle(\PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN)
    ->getColor()->setRGB('00B0F0');

$sheet->getRowDimension('7')->setRowHeight(10);
    
// Merge cells for the another title
$sheet->mergeCells('A8:P8'); // Merge cells for the title starting from row 6
$sheet->setCellValue('A8', 'COMPASS - MANILA BRANCH'); // Set the title starting from row 6

// Style the title
$sheet->getStyle('A8')->getFont()->setBold(false)->setSize(14);
$sheet->getStyle('A8')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);

// Merge cells for the another title
$sheet->mergeCells('A9:P9'); // Merge cells for the title starting from row 6
$sheet->setCellValue('A9', 'PROPERTY AND ASSET MANAGEMENT'); // Set the title starting from row 6

// Style the title
$sheet->getStyle('A9')->getFont()->setBold(false)->setSize(14);
$sheet->getStyle('A9')->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);

$sheet->getRowDimension('10')->setRowHeight(10);


// Set headers
$headers = array(
    'Property Code',
    'Item Category',
    'Classification',
    'Brand / Model',
    'Description',
    'Acquisition Date',
    'Purchased Value',
    'Depreciation Value',
    'Department / Unit',
    'Issued To',
    'Location (Bldg/Room)',
    'Serial No./ISBN',
    'Ref No.',
    'Life Expectancy',
    'Status',
    'Maintenance'
);


for ($col = 'A'; $col != 'Q'; ++$col) {
    $cellRange = $col . '11:' . $col . '12';
    $sheet->mergeCells($cellRange);
    $sheet->getStyle($cellRange)->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::HORIZONTAL_CENTER);
    $sheet->getStyle($cellRange)->getAlignment()->setHorizontal(\PhpOffice\PhpSpreadsheet\Style\Alignment::VERTICAL_CENTER);
    $sheet->getStyle($cellRange)->getFont()->setBold(true);
    $sheet->getStyle($cellRange)->getBorders()->getAllBorders()->setBorderStyle(\PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN)->getColor()->setRGB('000000');
}




$sheet->fromArray($headers, NULL, 'A11'); // Starting from A7 to leave space for the image and title


// Adjust the row index for data accordingly
$rowIndex = 13; // Starting from the eighth row for data


if(isset($_GET['empQuery'])){
    $empRecords = $conn1->query($_GET['empQuery']);
    $currYear = date("Y");
} else {
    echo "<script>alert('Something went wrong');</script>";
    exit;
}

while ($row = $empRecords->fetch_assoc()) {
    $purchased_value = isset($row['purchased_value']) ? floatval($row['purchased_value']) : null;
    $year_passed = isset($row['date_acquired']) ? ($currYear - date('Y', strtotime($row['date_acquired']))) : null;
    $salvage_value = ($purchased_value && (isset($row['life_expectancy']) && ($row['life_expectancy'] > 0))) ? $purchased_value / floatval($row['life_expectancy']) : null;
    $depreciation_value = ($purchased_value && $year_passed) ? round($purchased_value - ($salvage_value * $year_passed), 2) : "N/A";

    if($depreciation_value !== "N/A") {
        $depreciation_value = "Php " . $depreciation_value;
    }

    $maintenance = $row['maintenance'] ?? "N/A";
    if ($maintenance == 1) {
        $maintenance = "REQUIRED";
    } elseif ($maintenance == 0) {
        $maintenance = "NOT REQUIRED";
    }

    $sheet->fromArray(array(
        $row['propertyCode'] ?? 'N/A',
        $row['category'] ?? 'N/A',
        $row['classification'] ?? 'N/A',
        (isset($row['brand']) && isset($row['model'])) ? $row['brand'] . " / " . $row['model'] : 'N/A',
        $row['description'] ?? 'N/A',
        $row['date_acquired'] ?? 'N/A',
        (isset($row['purchased_value']) && $row['purchased_value'] !== '') ? "Php " . trim($row['purchased_value']) : 'N/A',
        $depreciation_value,
        $row['department'] ?? 'N/A',
        $row['issued_to'] ?? 'N/A',
        $row['location'] ?? 'N/A',
        $row['ISBN'] ?? 'N/A',
        $row['PO_Ref_No'] ?? 'N/A',
        (isset($row['life_expectancy']) && $row['life_expectancy'] !== '') ? $row['life_expectancy'] . " year/s" : 'N/A',
        $row['status'] ?? 'N/A',
        $maintenance
    ), NULL, 'A' . $rowIndex);

    $rowIndex++;
}

// Set column widths
foreach(range('A','P') as $columnID) {
    $sheet->getColumnDimension($columnID)->setAutoSize(true);
}

// Add borders to all cells containing data
$lastRow = $sheet->getHighestRow();
$lastColumn = $sheet->getHighestColumn();
$cellRange = 'A11:' . $lastColumn . $lastRow;
$sheet->getStyle($cellRange)->getBorders()->getAllBorders()->setBorderStyle(\PhpOffice\PhpSpreadsheet\Style\Border::BORDER_THIN)->getColor()->setRGB('000000');

// Write the spreadsheet to a file
$writer = new Xlsx($spreadsheet);
$filename = 'inventory_list.xlsx';

header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment; filename="' . $filename . '"');
header('Cache-Control: max-age=0');
$writer->save('php://output');
?>
