<?php
require 'vendor/autoload.php';

use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Worksheet\Drawing;
use PhpOffice\PhpSpreadsheet\Style\Alignment;
use PhpOffice\PhpSpreadsheet\Style\Border;
use PhpOffice\PhpSpreadsheet\Style\Fill;

include('../../database/dbcon.php');
function convertDate($dateString, $dateType)
{
    // Convert $firstDay into DateTime format
    $date = DateTime::createFromFormat('Y-m-d', $dateString); // Correct format 'Y-m-d'
    if ($dateType == 1) {
        return $date->format('M. j, Y'); // Correct output format: Dec 1, 2024  
    } else if ($dateType == 2) {
        return $date->format('M. j'); // Correct output format: Dec 1, 2024  
    }
}

// Function to add header and design elements for a specific department
function addDesignElements($sheet, $departmentName)
{
    // Add image to the worksheet
    $drawing = new Drawing();
    $drawing->setPath('../img/compass-main-logo.png'); // Path to your image file
    $drawing->setCoordinates('A1'); // Position at A1
    $drawing->setOffsetX(-10); // Horizontal position
    $drawing->setOffsetY(10); // Vertical position
    $drawing->setWidthAndHeight(225, 75); // Set width and height
    $drawing->setWorksheet($sheet);

    // Adjust row heights to ensure there's enough space for the image
    $sheet->getRowDimension('1')->setRowHeight(15); // Increase height for the image
    $sheet->getRowDimension('2')->setRowHeight(10);
    $sheet->getRowDimension('3')->setRowHeight(10);
    $sheet->getRowDimension('4')->setRowHeight(10);
    $sheet->getRowDimension('5')->setRowHeight(10);

    // Add document details to the top right corner
    $details = "Doc ID: _________\nRevision No. ____\nDate Approved: __________________\nInternal";
    $lines = explode("\n", $details);

    $lineIndex = 2;
    $colIndex = 'F'; // Adjusted for new column range

    for ($i = 0; $i < count($lines); ++$i) {
        $sheet->setCellValue($colIndex . $lineIndex, $lines[$i]);
        $sheet->getStyle($colIndex . $lineIndex)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_RIGHT);
        $sheet->getStyle($colIndex . $lineIndex)->getFont()->setItalic(true)->setSize(5)->setName('Arial');
        $lineIndex++;
    }

    // Set row height for document details
    for ($row = 2; $row < $lineIndex; $row++) {
        $sheet->getRowDimension($row)->setRowHeight(7.5);
    }

    // Add an empty row for spacing
    $sheet->insertNewRowBefore(8, 3); // Insert three empty rows starting from row 7

    // Merge cells for the title
    $sheet->mergeCells('A7:F7'); // Adjusted for new column range
    $sheet->setCellValue('A7', 'MAINTENANCE' . "\n " . 'WEEKLY' . "\n " . 'COMPLETION' . "\n " . 'REPORT');
    $sheet->getStyle('A7')->getFont()->setBold(true)->setSize(12)->setName('Arial');
    $sheet->getStyle('A7')->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
    $sheet->getStyle('A7:F7')->getBorders()->getBottom()->setBorderStyle(Border::BORDER_THIN)
        ->getColor()->setRGB('00B0F0');

    $sheet->getRowDimension('8')->setRowHeight(10);

    if (isset($_GET['start_date']) && !empty($_GET['start_date'])) {
        $date = new DateTime($_GET['start_date']);
        $coveredDate = "Week " . $date->format("W") . "(" . convertDate($_GET['start_date'], 1) . " - " . ")";
    }
    if (isset($_GET['end_date']) && !empty($_GET['end_date'])) {
        $date = new DateTime($_GET['end_date']);
        $coveredDate = "Week " . $date->format("W") . "(" . " - " . convertDate($_GET['end_date'], 1) . ")";
    }
    if ((isset($_GET['start_date']) && !empty($_GET['start_date'])) && (isset($_GET['end_date']) && !empty($_GET['end_date']))) {
        $date1 = new DateTime($_GET['start_date']);
        $date2 = new DateTime($_GET['end_date']);
        if ($date1->format("W") == $date2->format("W")) {
            $weekNumber = $date1->format("W");
        } else {
            $weekNumber =  $date1->format("W") . " - " . $date2->format("W");
        }
        $coveredDate = "Week " . $weekNumber . " (" . convertDate($_GET['start_date'], 2) . " - " . convertDate($_GET['end_date'], 1) . ")";
    } else {
        $coveredDate = "All Time";
    }

    $sheet->setCellValue('A9', "Covered Period: " . $coveredDate);
    $sheet->getStyle('A9')->getFont()->setBold(true)->setSize(11)->setName('Arial');

    // Add department title and merge cells A10:F11
    $sheet->mergeCells('A10:F11'); // Merging cells A10 to F11
    $sheet->setCellValue('A10', strtoupper($departmentName)); // Use the department name

    // Define the style array with bold font
    $styleArray = [
        'font' => [
            'bold' => true, // Make font bold
            'size' => 12,
            'name' => 'Arial',
            'color' => ['rgb' => 'FFFFFF'] // Set text color to white
        ],
        'alignment' => [
            'horizontal' => Alignment::HORIZONTAL_CENTER,
            'vertical' => Alignment::VERTICAL_CENTER, // Set vertical alignment to center
        ],
        'fill' => [
            'fillType' => Fill::FILL_SOLID,
            'startColor' => ['rgb' => '002060'] // Set background color to dark blue
        ],
        'borders' => [
            'bottom' => [
                'borderStyle' => Border::BORDER_THIN,
                'color' => ['rgb' => '000000']
            ]
        ]
    ];

    $sheet->getStyle('A10:F11')->applyFromArray($styleArray);

    // Add border only to the top of the next section
    $sheet->getStyle('A12:F12')->getBorders()->getTop()->setBorderStyle(Border::BORDER_THIN)->getColor()->setRGB('000000');

    // Set headers to match the table columns (without 'Action')
    $headers = [
        'CATEGORY',
        'LOCATION',
        'DETAILS',
        'STATUS',
        'COMPLETION DATE',
        'REMARKS'
    ];
    $sheet->fromArray($headers, NULL, 'A12'); // Start headers from row 12

    // Style the headers
    $headerRange = 'A12:F12'; // Adjusted to row 12
    $sheet->getStyle($headerRange)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
    $sheet->getStyle($headerRange)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER); // Add vertical alignment
    $sheet->getStyle($headerRange)->getFont()->getColor()->setRGB('000000'); // Font color white
    $sheet->getStyle($headerRange)->getFont()->setBold(true); // Bold headers

    // Add black borders to header cells
    $sheet->getStyle($headerRange)->getBorders()->getAllBorders()->setBorderStyle(Border::BORDER_THIN)->getColor()->setRGB('000000');

    // Set row height
    $sheet->getRowDimension('12')->setRowHeight(30);

    // Set fixed column widths
    $columnWidths = [30, 30, 45, 20, 30, 60]; // Widths for columns A to F
    foreach (range('A', 'F') as $i => $columnID) {
        $sheet->getColumnDimension($columnID)->setWidth($columnWidths[$i]);
    }

    // Add a wider column for 'Remarks' up to column G

    // Set page orientation, size, and scaling
    $sheet->getPageSetup()->setOrientation(\PhpOffice\PhpSpreadsheet\Worksheet\PageSetup::ORIENTATION_LANDSCAPE);
    $sheet->getPageSetup()->setPaperSize(\PhpOffice\PhpSpreadsheet\Worksheet\PageSetup::PAPERSIZE_A4); // Change to PAPERSIZE_LETTER for Letter size
    $sheet->getPageSetup()->setFitToPage(true);
    $sheet->getPageSetup()->setFitToWidth(1);
    $sheet->getPageSetup()->setFitToHeight(0);
}

// Function to add borders to all cells containing data
function addBorders($sheet, $startRow, $endRow)
{
    $lastColumn = 'F';  // Set last column to F
    $cellRange = 'A' . $startRow . ':' . $lastColumn . $endRow;
    $sheet->getStyle($cellRange)->getBorders()->getAllBorders()->setBorderStyle(Border::BORDER_THIN)->getColor()->setRGB('000000'); // Set border color to black
}

// Create new Spreadsheet object
$spreadsheet = new Spreadsheet();

// Get the query from the URL parameter and validate it
if (isset($_GET['empQuery']) && !empty($_GET['empQuery'])) {
    // Sanitize input to prevent SQL injection
    $empQuery = $_GET['empQuery'];

    // Check if the sanitized query is not empty
    if (!empty($empQuery)) {
        $empRecords = $conn1->query($empQuery);

        if (!$empRecords) {
            echo "<script>alert('Error executing query: " . $conn1->error . "');</script>";
            exit;
        }
    } else {
        echo "<script>alert('The query parameter is empty.');</script>";
        exit;
    }
} else {
    echo "<script>alert('Query parameter is missing or empty.');</script>";
    exit;
}

// Group records by department
$departmentData = [];
while ($data = $empRecords->fetch_assoc()) {
    $department = $data['department'] ?? 'Unknown Department';
    $departmentData[$department][] = $data;
}

// Populate the sheet with data grouped by department
foreach ($departmentData as $departmentName => $records) {
    // Initialize a new worksheet for each department
    $sheet = $spreadsheet->createSheet();
    $sheet->setTitle(substr($departmentName, 0, 31)); // Set the sheet title to the department name
    addDesignElements($sheet, $departmentName); // Pass department name

    $dataRowIndex = 13; // Start row for data

    // Populate each department's sheet with data
    foreach ($records as $data) {
        // Add the data to the sheet
        if (strtolower($data['status'] ?? '') == "done") { // Check if the project status is ongoing
            $sheet->fromArray([
                $data['category'] ?? 'N/A',
                $data['location'] ?? 'N/A',
                $data['details'] ?? 'N/A',
                $data['status'] ?? 'N/A',
                $data['completion_date'] ?? 'N/A',
                $data['remarks'] ?? 'N/A'
            ], NULL, 'A' . $dataRowIndex);

            // Adjust the row height for remarks if needed
            $remarksLength = strlen($data['remarks'] ?? '');
            if ($remarksLength > 100) { // Arbitrary length for demonstration
                $sheet->getRowDimension($dataRowIndex)->setRowHeight(30); // Increase row height if remarks are long
            } else {
                $sheet->getRowDimension($dataRowIndex)->setRowHeight(15); // Default row height
            }

            $dataRowIndex++;
        }
    }

    // Add borders to the sheet if it contains data
    if ($dataRowIndex > 13) {
        addBorders($sheet, 13, $dataRowIndex - 1);
    }

    // Add space before the ongoing projects table
    $dataRowIndex += 2;

    // Set header for ongoing projects section
    $headerRow = $dataRowIndex; // Define the row for the header
    $ongoingHeaderRange = 'A' . $headerRow . ':F' . $headerRow; // Define the range for merging and styling

    // Merge cells for the header
    $sheet->mergeCells($ongoingHeaderRange);

    // Set the cell value for the header
    $sheet->setCellValue('A' . $headerRow, 'ON GOING PROJECTS');

    // Apply styles for the header
    $sheet->getStyle($ongoingHeaderRange)->applyFromArray([
        'font' => [
            'bold' => true,
            'size' => 12,
            'name' => 'Arial',
        ],
        'alignment' => [
            'horizontal' => Alignment::HORIZONTAL_CENTER,
            'vertical' => Alignment::VERTICAL_CENTER,
        ],
        'fill' => [
            'fillType' => Fill::FILL_SOLID,
            'startColor' => ['rgb' => 'A6A6A6'], // Set background color to #A6A6A6
        ],
        'borders' => [
            'allBorders' => [
                'borderStyle' => Border::BORDER_THIN,
                'color' => ['rgb' => '000000'], // Set border color to black
            ],
        ],
    ]);

    // Set the row height for the "ON GOING PROJECTS" header
    $sheet->getRowDimension($headerRow)->setRowHeight(15); // Adjust height as needed

    // Style the header
    $sheet->getStyle('A' . $headerRow)->applyFromArray([
        'font' => [
            'bold' => true,
            'size' => 12,
            'name' => 'Arial',
        ],
        'alignment' => [
            'horizontal' => Alignment::HORIZONTAL_CENTER,
            'vertical' => Alignment::VERTICAL_CENTER,
        ],
        'fill' => [
            'fillType' => Fill::FILL_SOLID,
            'startColor' => ['rgb' => 'A6A6A6'], // Set background color to #A6A6A6
        ],
        'borders' => [
            'outline' => [
                'borderStyle' => Border::BORDER_THIN,
                'color' => ['rgb' => '000000'], // Set border color to black
            ],
        ],
    ]);

    // Set the row height for the "ON GOING PROJECTS" header
    $sheet->getRowDimension($headerRow)->setRowHeight(15); // Adjust height as needed

    // Add a header row for ongoing projects
    $ongoingHeaders = [
        'CATEGORY',
        'DEPARTMENT',
        'DETAILS',
        'STATUS',
        'TARGET COMPLETION DATE',
        'REMARKS'
    ];
    $sheet->fromArray($ongoingHeaders, NULL, 'A' . ($dataRowIndex + 1)); // Start headers from the next row

    // Style the ongoing project headers
    $ongoingHeaderRange = 'A' . ($dataRowIndex + 1) . ':F' . ($dataRowIndex + 1); // Adjusted to row for headers
    $sheet->getStyle($ongoingHeaderRange)->getAlignment()->setHorizontal(Alignment::HORIZONTAL_CENTER);
    $sheet->getStyle($ongoingHeaderRange)->getAlignment()->setVertical(Alignment::VERTICAL_CENTER); // Add vertical alignment
    $sheet->getStyle($ongoingHeaderRange)->getFont()->getColor()->setRGB('000000'); // Font color white
    $sheet->getStyle($ongoingHeaderRange)->getFont()->setBold(true); // Bold headers

    // Add black borders to ongoing project header cells
    $sheet->getStyle($ongoingHeaderRange)->getBorders()->getAllBorders()->setBorderStyle(Border::BORDER_THIN)->getColor()->setRGB('000000');

    // Set row height for ongoing project headers
    $sheet->getRowDimension($dataRowIndex + 1)->setRowHeight(30);

    // Populate ongoing projects data
    $ongoingRowIndex = $dataRowIndex + 2; // Start from the next row
    foreach ($records as $data) {
        if (strtolower($data['status'] ?? '') == "ongoing") { // Check if the project status is ongoing
            $sheet->fromArray([
                $data['category'] ?? 'N/A',
                $data['department'] ?? 'N/A',
                $data['details'] ?? 'N/A',
                $data['status'] ?? 'N/A',
                $data['completion_date'] ?? 'N/A',
                $data['remarks'] ?? 'N/A'
            ], NULL, 'A' . $ongoingRowIndex);

            // Adjust the row height for remarks if needed
            $remarksLength = strlen($data['remarks'] ?? '');
            if ($remarksLength > 100) { // Arbitrary length for demonstration
                $sheet->getRowDimension($ongoingRowIndex)->setRowHeight(30); // Increase row height if remarks are long
            } else {
                $sheet->getRowDimension($ongoingRowIndex)->setRowHeight(15); // Default row height
            }

            $ongoingRowIndex++;
        }
    }

    // Add borders to the ongoing projects table if it contains data
    if ($ongoingRowIndex > ($dataRowIndex + 2)) {
        addBorders($sheet, $dataRowIndex + 2, $ongoingRowIndex - 1);
    }
}

// Remove the default empty sheet created with the new Spreadsheet
$spreadsheet->removeSheetByIndex(0);

// Write the spreadsheet to a file and force download
$writer = new Xlsx($spreadsheet);
$filename = 'Maintenance Weekly Completion Report.xlsx';

header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
header('Content-Disposition: attachment; filename="' . $filename . '"');
header('Cache-Control: max-age=0');
$writer->save('php://output');
exit;
